@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
  * @ingroup ffmpegfs
  *
  * @author Norbert Schlia (nschlia@oblivion-software.de)
- * @copyright Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * @copyright Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  */
 
 #include "blurayio.h"
@@ -37,7 +37,6 @@
 #include "logging.h"
 
 #include <libbluray/bluray.h>
-#include <assert.h>
 
 BlurayIO::BlurayIO()
     : m_bd(nullptr)
@@ -59,7 +58,7 @@ BlurayIO::BlurayIO()
 
 BlurayIO::~BlurayIO()
 {
-    _close();
+    pvt_close();
 }
 
 VIRTUALTYPE BlurayIO::type() const
@@ -72,7 +71,7 @@ size_t BlurayIO::bufsize() const
     return sizeof(m_data);
 }
 
-int BlurayIO::open(LPVIRTUALFILE virtualfile)
+int BlurayIO::openio(LPVIRTUALFILE virtualfile)
 {
     const char *bdpath = nullptr;
     uint32_t title_count;
@@ -128,7 +127,7 @@ int BlurayIO::open(LPVIRTUALFILE virtualfile)
 
     if (m_angle_idx >= ti->angle_count)
     {
-        Logging::warning(bdpath, "The angle %1 is greate than the angle count %2. Using angle 1.", m_angle_idx + 1, ti->angle_count);
+        Logging::warning(bdpath, "The angle %1 is greater than the angle count %2. Using angle 1.", m_angle_idx + 1, ti->angle_count);
         m_angle_idx = 0;
     }
 
@@ -174,7 +173,7 @@ int BlurayIO::open(LPVIRTUALFILE virtualfile)
     return 0;
 }
 
-size_t BlurayIO::read(void * data, size_t size)
+size_t BlurayIO::readio(void * data, size_t size)
 {
     size_t result_len = 0;
 
@@ -304,12 +303,12 @@ bool BlurayIO::eof() const
     return (m_cur_pos >= m_end_pos);
 }
 
-void BlurayIO::close()
+void BlurayIO::closeio()
 {
-    _close();
+    pvt_close();
 }
 
-void BlurayIO::_close()
+void BlurayIO::pvt_close()
 {
     BLURAY * bd = m_bd;
     if (bd != nullptr)
