@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
  * @ingroup ffmpegfs
  *
  * @author Norbert Schlia (nschlia@oblivion-software.de)
- * @copyright Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * @copyright Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  */
 
 #include "buffer.h"
@@ -37,7 +37,6 @@
 #include <unistd.h>
 #include <sys/mman.h>
 #include <libgen.h>
-#include <assert.h>
 
 // Initially Buffer is empty. It will be allocated as needed.
 Buffer::Buffer()
@@ -62,7 +61,7 @@ size_t Buffer::bufsize() const
     return 0;   // Not applicable
 }
 
-int Buffer::open(LPVIRTUALFILE virtualfile)
+int Buffer::openio(LPVIRTUALFILE virtualfile)
 {
     if (virtualfile == nullptr)
     {
@@ -253,7 +252,7 @@ bool Buffer::init(bool erase_cache)
                 Logging::error(m_ci[0].m_cachefile, "INTERNAL ERROR: Buffer::init()! Frame count is zero (%1) %2", errno, strerror(errno));
                 throw false;
             }
-            assert(sizeof(IMAGE_FRAME) == 32);
+            static_assert(sizeof(IMAGE_FRAME) == 32, "sizeof(IMAGE_FRAME) must be 32 bytes");
 
             size_t filesize     = 0;
             bool isdefaultsize  = false;
@@ -338,7 +337,7 @@ bool Buffer::segment_exists(uint32_t segment_no)
 
     if (!segment_count() || m_cur_ci == nullptr)
     {
-        return 0;
+        return false;
     }
     return file_exists(m_ci[segment_no - 1].m_cachefile);
 }
@@ -425,42 +424,42 @@ bool Buffer::unmap_file(const std::string &filename, int * fd, uint8_t **p, size
 
     Logging::trace(filename, "Unmapping cache file.");
 
-    void *  __p         = *p;
-    size_t  __filesize  = *filesize;
-    int     __fd        = *fd;
+    void *  _p         = *p;
+    size_t  _filesize  = *filesize;
+    int     _fd        = *fd;
 
     // Clear all variables
     *p          = nullptr;
     *filesize   = 0;
     *fd         = -1;
 
-    if (__p != nullptr)
+    if (_p != nullptr)
     {
-        if (munmap(__p, len ? len : static_cast<size_t>(sysconf(_SC_PAGESIZE))) == -1) // Make sure we do not unmap a zero size file (spits EINVAL error)
+        if (munmap(_p, len ? len : static_cast<size_t>(sysconf(_SC_PAGESIZE))) == -1) // Make sure we do not unmap a zero size file (spits EINVAL error)
         {
             Logging::error(filename, "Unmapping cache file failed: (%1) %2 Size: %3", errno, strerror(errno), len);
             success = false;
         }
     }
 
-    if (__fd != -1)
+    if (_fd != -1)
     {
-        if (__filesize)
+        if (_filesize)
         {
-            if (ftruncate(__fd, static_cast<off_t>(__filesize)) == -1)
+            if (ftruncate(_fd, static_cast<off_t>(_filesize)) == -1)
             {
-                Logging::error(filename, "Error calling ftruncate() to resize and close the cache file: (%1) %2 (fd = %3) Size: %5", errno, strerror(errno), __fd, __filesize);
+                Logging::error(filename, "Error calling ftruncate() to resize and close the cache file: (%1) %2 (fd = %3) Size: %5", errno, strerror(errno), _fd, _filesize);
                 success = false;
             }
-            ::close(__fd);
+            ::close(_fd);
         }
         else
         {
-            ::close(__fd);
+            ::close(_fd);
 
             if (unlink(filename.c_str()) && errno != ENOENT)    // Ignore if file does not exist
             {
-                Logging::error(filename, "Error removing the cache file: (%1) %2 (fd = %3)", errno, strerror(errno), __fd);
+                Logging::error(filename, "Error removing the cache file: (%1) %2 (fd = %3)", errno, strerror(errno), _fd);
                 success = false;
             }
         }
@@ -609,7 +608,7 @@ bool Buffer::reserve(size_t size)
     if (m_cur_ci == nullptr || m_cur_ci->m_buffer == nullptr)
     {
         errno = ENOMEM;
-        //Logging::error(m_cur_ci->m_cachefile, "Error in resize(): (%1) %2 (fd = %3)", errno, strerror(errno), m_cur_ci->m_fd);
+        Logging::error(nullptr, "INTERNAL ERROR: Buffer::reserve()!");
         return false;
     }
 
@@ -639,7 +638,7 @@ bool Buffer::reserve(size_t size)
     return true;
 }
 
-size_t Buffer::write(const uint8_t* data, size_t length)
+size_t Buffer::writeio(const uint8_t* data, size_t length)
 {
     std::lock_guard<std::recursive_mutex> lck (m_mutex);
 
@@ -688,7 +687,7 @@ size_t Buffer::write_frame(const uint8_t *data, size_t length, uint32_t frame_no
 
         // Write image
         seek(static_cast<long>(old_image_frame->m_offset), SEEK_SET);
-        bytes_written = write(data, old_image_frame->m_size);
+        bytes_written = writeio(data, old_image_frame->m_size);
         if (bytes_written != old_image_frame->m_size)
         {
             return 0;
@@ -705,7 +704,7 @@ size_t Buffer::write_frame(const uint8_t *data, size_t length, uint32_t frame_no
 
         // Write image
         seek(static_cast<long>(new_image_frame.m_offset), SEEK_SET);
-        bytes_written = write(data, new_image_frame.m_size);
+        bytes_written = writeio(data, new_image_frame.m_size);
         if (bytes_written != new_image_frame.m_size)
         {
             return 0;
@@ -873,21 +872,30 @@ bool Buffer::copy(uint8_t* out_data, size_t offset, size_t bufsize, uint32_t seg
         return false;
     }
 
+    size_t segment_size = size(segment_no);
+
+    if (ci->m_buffer_size != segment_size)
+    {
+        Logging::error(m_cur_ci->m_cachefile, "INTERNAL ERROR: Buffer::copy()! ci->m_buffer_size != segment_size - Segment: %1 ci->m_buffer_size: %2 segment_size: %3", segment_no, ci->m_buffer_size, segment_size);
+        errno = ESPIPE; // Comes from size()
+        return false;
+    }
+
     bool success = true;
 
-    assert(ci->m_buffer_size == size(segment_no));
-    if (size(segment_no) >= offset)
+    if (segment_size >= offset)
     {
-        if (size(segment_no) < offset + bufsize)
+        if (segment_size < offset + bufsize)
         {
-            bufsize = size(segment_no) - offset - 1;
+            bufsize = segment_size - offset - 1;
         }
 
         memcpy(out_data, ci->m_buffer + offset, bufsize);
     }
     else
     {
-        errno = ESPIPE; // Changed from ENOMEM because this was misleading.
+        Logging::error(m_cur_ci->m_cachefile, "INTERNAL ERROR: Buffer::copy()! size(segment_no) < offset - Segment: %1 Size: %2 Offset: %3", segment_no, segment_size, offset);
+        errno = ESPIPE;
         success = false;
     }
 
@@ -958,7 +966,7 @@ bool Buffer::remove_file(const std::string & filename)
     }
 }
 
-size_t Buffer::read(void * /*data*/, size_t /*size*/)
+size_t Buffer::readio(void * /*data*/, size_t /*size*/)
 {
     // Not implemented
     errno = EPERM;
@@ -1007,7 +1015,7 @@ bool Buffer::eof(uint32_t segment_no) const
     return (tell(segment_no) == size(segment_no));
 }
 
-void Buffer::close()
+void Buffer::closeio()
 {
     release();
 }
@@ -1077,7 +1085,6 @@ Buffer::LPCACHEINFO Buffer::cacheinfo(uint32_t segment_no)
     {
         segment_no--;
 
-        assert(segment_no < segment_count());
         if (segment_no >= segment_count())
         {
             return nullptr;
@@ -1094,7 +1101,6 @@ Buffer::LPCCACHEINFO Buffer::const_cacheinfo(uint32_t segment_no) const
     {
         segment_no--;
 
-        assert(segment_no < m_ci.size());
         if (segment_no >= m_ci.size())
         {
             return nullptr;
