@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
  * @ingroup ffmpegfs
  *
  * @author Norbert Schlia (nschlia@oblivion-software.de)
- * @copyright Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * @copyright Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  */
 
 #include "cache_entry.h"
@@ -34,7 +34,7 @@
 #include "buffer.h"
 #include "logging.h"
 
-#include <string.h>
+#include <cstring>
 
 Cache_Entry::Cache_Entry(Cache *owner, LPVIRTUALFILE virtualfile)
     : m_owner(owner)
@@ -52,7 +52,7 @@ Cache_Entry::Cache_Entry(Cache *owner, LPVIRTUALFILE virtualfile)
 
     if (m_buffer != nullptr)
     {
-        m_buffer->open(virtualfile);
+        m_buffer->openio(virtualfile);
     }
 
     clear();
@@ -160,7 +160,7 @@ bool Cache_Entry::update_access(bool update_database /*= false*/)
     }
 }
 
-bool Cache_Entry::open(bool create_cache /*= true*/)
+bool Cache_Entry::openio(bool create_cache /*= true*/)
 {
     if (m_buffer == nullptr)
     {
@@ -216,7 +216,7 @@ void Cache_Entry::close_buffer(int flags)
     }
 }
 
-bool Cache_Entry::close(int flags)
+bool Cache_Entry::closeio(int flags)
 {
     write_info();
 
