@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
  * @ingroup ffmpegfs
  *
  * @author Norbert Schlia (nschlia@oblivion-software.de)
- * @copyright Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * @copyright Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  */
 
 #include "cache_maintenance.h"
@@ -34,7 +34,7 @@
 #include "ffmpeg_utils.h"
 #include "logging.h"
 
-#include <signal.h>
+#include <csignal>
 #include <unistd.h>
 #include <sys/shm.h>        /* shmat(), IPC_RMID        */
 #include <semaphore.h>      /* sem_open(), sem_destroy(), sem_wait().. */
@@ -286,7 +286,7 @@ static bool link_down()
 
     Logging::info(nullptr, "Shutting " PACKAGE " inter-process link down.");
 
-    if (sem_close(sem))
+    if (sem != nullptr && sem_close(sem))
     {
         Logging::error(nullptr, "link_down(): sem_close error (%1) %2", errno, strerror(errno));
         success = false;
