@@ -1,5 +1,5 @@
-﻿/*
- * Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+/*
+ * Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
  * @ingroup ffmpegfs
  *
  * @author Norbert Schlia (nschlia@oblivion-software.de)
- * @copyright Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * @copyright Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  */
 
 #include "ffmpegfs.h"
@@ -150,16 +150,15 @@ static bool create_cuesheet_virtualfile(LPCVIRTUALFILE virtualfile, Track *track
         duration            = *remainingduration;
     }
 
-    char title_buf[PATH_MAX + 1];
+    std::string virtfilename;
 
-    snprintf(title_buf, sizeof(title_buf) - 1, "%02d. %s - %s [%s].%s",
+    strsprintf(&virtfilename, "%02d. %s - %s [%s].%s",
              titleno,
              performer.c_str(),
              title.c_str(),
              replace_all(format_duration(duration), ":", "-").c_str(),
              ffmpeg_format[virtualfile->m_format_idx].fileext().c_str());
 
-    std::string virtfilename(title_buf);
     // Filenames can't contain '/' in POSIX etc.
     std::replace(virtfilename.begin(), virtfilename.end(), '/', '-');
 
@@ -193,7 +192,7 @@ static bool create_cuesheet_virtualfile(LPCVIRTUALFILE virtualfile, Track *track
         int width               = 0;
         int height              = 0;
         AVRational framerate    = { 0, 0 };
-        int interleaved         = 0;
+        bool interleaved        = false;
 
         newvirtualfile->m_duration                      = duration;
         newvirtualfile->m_cuesheet_track.m_duration     = duration;
@@ -368,7 +367,6 @@ static int parse_cuesheet(LPCVIRTUALFILE virtualfile, const std::string & cueshe
 
 int check_cuesheet(const std::string & filename, void *buf, fuse_fill_dir_t filler)
 {
-    std::string origfile(filename);     // Name of physical file
     std::string trackdir(filename);     // Tracks directory (with extra TRACKDIR extension)
     std::string cuesheet(filename);     // Cue sheet name (original name, extension replaced by .cue)
     struct stat stbuf;
@@ -380,7 +378,7 @@ int check_cuesheet(const std::string & filename, void *buf, fuse_fill_dir_t fill
 
     try
     {
-        LPCVIRTUALFILE virtualfile = find_file_from_orig(origfile);
+        LPCVIRTUALFILE virtualfile = find_file_from_orig(filename);
 
         if (virtualfile == nullptr)
         {
@@ -390,13 +388,13 @@ int check_cuesheet(const std::string & filename, void *buf, fuse_fill_dir_t fill
             throw -errno;
         }
 
-        if (lstat(origfile.c_str(), &stbuf) == -1)
+        if (stat(filename.c_str(), &stbuf) == -1)
         {
             // Media file does not exist, can be ignored silently
             throw 0;
         }
 
-        if (lstat(cuesheet.c_str(), &stbuf) != -1)
+        if (stat(cuesheet.c_str(), &stbuf) != -1)
         {
             // Cue sheet file exists, preferrably use its contents
             if (!check_path(trackdir))
@@ -417,7 +415,7 @@ int check_cuesheet(const std::string & filename, void *buf, fuse_fill_dir_t fill
 
                 if (virtualdir == nullptr)
                 {
-                    Logging::error(origfile, "INTERNAL ERROR: check_cuesheet()! virtualdir is NULL.");
+                    Logging::error(filename, "INTERNAL ERROR: check_cuesheet()! virtualdir is NULL.");
                     errno = EIO;
                     throw -errno;
                 }
