@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,14 +26,14 @@
  * @ingroup ffmpegfs
  *
  * @author Norbert Schlia (nschlia@oblivion-software.de)
- * @copyright Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * @copyright Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  */
 
 #include "diskio.h"
 #include "ffmpegfs.h"
 #include "logging.h"
 
-#include <errno.h>
+#include <cerrno>
 
 DiskIO::DiskIO()
     : m_fpi(nullptr)
@@ -43,7 +43,7 @@ DiskIO::DiskIO()
 
 DiskIO::~DiskIO()
 {
-    _close();
+    pvt_close();
 }
 
 VIRTUALTYPE DiskIO::type() const
@@ -56,7 +56,7 @@ size_t DiskIO::bufsize() const
     return (100 /* KB */ * 1024);
 }
 
-int DiskIO::open(LPVIRTUALFILE virtualfile)
+int DiskIO::openio(LPVIRTUALFILE virtualfile)
 {
     set_virtualfile(virtualfile);
 
@@ -74,7 +74,7 @@ int DiskIO::open(LPVIRTUALFILE virtualfile)
     }
 }
 
-size_t DiskIO::read(void * data, size_t size)
+size_t DiskIO::readio(void * data, size_t size)
 {
     return fread(data, 1, size, m_fpi);
 }
@@ -117,12 +117,12 @@ bool DiskIO::eof() const
     return feof(m_fpi) ? true : false;
 }
 
-void DiskIO::close()
+void DiskIO::closeio()
 {
-    _close();
+    pvt_close();
 }
 
-void DiskIO::_close()
+void DiskIO::pvt_close()
 {
     FILE *fpi = m_fpi;
     if (fpi != nullptr)
