@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
  * @ingroup ffmpegfs
  *
  * @author Norbert Schlia (nschlia@oblivion-software.de)
- * @copyright Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * @copyright Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  */
 
 #include "dvdio.h"
@@ -36,8 +36,7 @@
 #include "ffmpeg_utils.h"
 #include "logging.h"
 
-#include <string.h>
-#include <assert.h>
+#include <cstring>
 
 #include <dvdread/dvd_reader.h>
 #include <dvdread/nav_read.h>
@@ -72,7 +71,7 @@ DvdIO::DvdIO()
 
 DvdIO::~DvdIO()
 {
-    _close();
+    pvt_close();
 }
 
 VIRTUALTYPE DvdIO::type() const
@@ -85,7 +84,7 @@ size_t DvdIO::bufsize() const
     return sizeof(m_data);
 }
 
-int DvdIO::open(LPVIRTUALFILE virtualfile)
+int DvdIO::openio(LPVIRTUALFILE virtualfile)
 {
     int pgc_id;
     int ttn;
@@ -209,7 +208,7 @@ int DvdIO::open(LPVIRTUALFILE virtualfile)
     m_size = 0;
     size_t bytes_read;
 
-    while ((bytes_read = read(nullptr, ULONG_MAX)) != 0 && !eof())
+    while ((bytes_read = readio(nullptr, ULONG_MAX)) != 0 && !eof())
     {
         m_size += bytes_read;
     }
@@ -257,7 +256,7 @@ bool DvdIO::get_packet_size(const uint8_t *p, size_t peek, size_t *size) const
         {
             if (peek >= 14 && (p[4] >> 6) == 0x01)
             {
-                *size = static_cast<size_t>(14 + (p[13] & 0x07)); // Byte 13 Bit 0..2: Pack stuffing length
+                *size = 14 + static_cast<size_t>(p[13] & 0x07); // Byte 13 Bit 0..2: Pack stuffing length
                 return true;
             }
             else if (peek >= 12 && (p[4] >> 4) == 0x02)
@@ -533,13 +532,13 @@ DvdIO::DSITYPE DvdIO::handle_DSI(void *_dsi_pack, size_t * cur_output_size, unsi
 void DvdIO::next_cell()
 {
     // Check if we're entering an angle block
-    if (m_cur_pgc->cell_playback[m_cur_cell].block_type == BLOCK_TYPE_ANGLE_BLOCK)
+    if (m_cur_pgc->cell_playback[m_cur_cell].block_type == static_cast<unsigned int>(BLOCK_TYPE_ANGLE_BLOCK))
     {
         m_cur_cell += m_angle_idx;
 
         for (int i = 0;; ++i)
         {
-            if (m_cur_pgc->cell_playback[m_cur_cell + i].block_mode == BLOCK_MODE_LAST_CELL)
+            if (m_cur_pgc->cell_playback[m_cur_cell + i].block_mode == static_cast<unsigned int>(BLOCK_MODE_LAST_CELL))
             {
                 m_next_cell = m_cur_cell + i + 1;
                 break;
@@ -552,7 +551,7 @@ void DvdIO::next_cell()
     }
 }
 
-size_t DvdIO::read(void * data, size_t size)
+size_t DvdIO::readio(void * data, size_t size)
 {
     size_t cur_output_size;
     size_t result_len = 0;
@@ -750,14 +749,12 @@ int DvdIO::seek(int64_t offset, int whence)
     switch (whence)
     {
     case SEEK_SET:
-        assert(offset >= 0);
         abs_offset = static_cast<size_t>(offset);
         break;
     case SEEK_CUR:
         abs_offset += cur_pos;
         break;
     case SEEK_END:
-        assert(offset >= 0);
         abs_offset = size() - abs_offset;
         break;
     default:
@@ -780,7 +777,7 @@ int DvdIO::seek(int64_t offset, int whence)
 
     size_t total_read = 0;
     size_t bytes_read;
-    while ((bytes_read = read(nullptr, abs_offset - total_read - cur_pos)) != 0 && total_read < abs_offset && !eof())
+    while ((bytes_read = readio(nullptr, abs_offset - total_read - cur_pos)) != 0 && total_read < abs_offset && !eof())
     {
         total_read += bytes_read;
     }
@@ -799,12 +796,12 @@ bool DvdIO::eof() const
     return m_is_eof;
 }
 
-void DvdIO::close()
+void DvdIO::closeio()
 {
-    _close();
+    pvt_close();
 }
 
-void DvdIO::_close()
+void DvdIO::pvt_close()
 {
     ifo_handle_t *  vts_file = m_vts_file;
     if (vts_file != nullptr)
@@ -866,11 +863,11 @@ bool DvdIO::is_nav_pack(const unsigned char *buffer) const
              buffer[0x403] == 0xbf &&
              buffer[0x406] == 0x01))
     {
-        return (1);
+        return true;
     }
     else
     {
-        return (0);
+        return false;
     }
 }
 
