@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
  * @ingroup ffmpegfs
  *
  * @author Norbert Schlia (nschlia@oblivion-software.de)
- * @copyright Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * @copyright Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  */
 
 #include "ffmpegfs.h"
@@ -202,7 +202,7 @@ static AVRational dvd_frame_rate(const uint8_t * ptr)
  */
 static int64_t BCDtime(const dvd_time_t * dvd_time)
 {
-    int64_t time[4];
+    std::array<int64_t, 4> time;
     AVRational  framerate = dvd_frame_rate(&dvd_time->frame_u);
 
     if (!framerate.den)
@@ -215,9 +215,9 @@ static int64_t BCDtime(const dvd_time_t * dvd_time)
     time[3] = dvd_time->frame_u & 0x3F;     // Number of frame
 
     // convert BCD (two digits) to binary
-    for (int i = 0; i < 4; i++)
+    for (int64_t & tm : time)
     {
-        time[i] = ((time[i] & 0xf0) >> 4) * 10 + (time[i] & 0x0f);
+        tm = ((tm & 0xf0) >> 4) * 10 + (tm & 0x0f);
     }
 
     return (AV_TIME_BASE * (time[0] * 3600 + time[1] * 60 + time[2]) + static_cast<int64_t>(static_cast<double>(AV_TIME_BASE * time[3]) / av_q2d(framerate)));
@@ -251,7 +251,7 @@ static bool create_dvd_virtualfile(const ifo_handle_t *vts_file, const std::stri
     AVRational framerate;
     int64_t duration        = 0;
     uint64_t size           = 0;
-    int interleaved         = 0;
+    bool interleaved        = false;
     int start_cell          = cur_pgc->program_map[pgn - 1] - 1;
     int end_cell            = 0;
 
@@ -264,7 +264,7 @@ static bool create_dvd_virtualfile(const ifo_handle_t *vts_file, const std::stri
         end_cell    = cur_pgc->nr_of_cells;
     }
 
-    interleaved         = cur_pgc->cell_playback[start_cell].interleaved;
+    interleaved         = cur_pgc->cell_playback[start_cell].interleaved ? true : false;
     framerate           = dvd_frame_rate(&cur_pgc->cell_playback[start_cell].playback_time.frame_u);
 
     bool has_angles = false;
@@ -274,13 +274,13 @@ static bool create_dvd_virtualfile(const ifo_handle_t *vts_file, const std::stri
         cell_playback_t *cell_playback = &cur_pgc->cell_playback[cell_no];
 
         // Only count normal cells and the first of an angle to avoid duplicate sizes
-        if (cell_playback->block_mode == BLOCK_MODE_NOT_IN_BLOCK || cell_playback->block_mode == BLOCK_MODE_FIRST_CELL)
+        if (cell_playback->block_mode == static_cast<unsigned int>(BLOCK_MODE_NOT_IN_BLOCK) || cell_playback->block_mode == static_cast<unsigned int>(BLOCK_MODE_FIRST_CELL))
         {
             size        += (cell_playback->last_sector - cell_playback->first_sector) * 2048;
             duration    += BCDtime(&cell_playback->playback_time);
         }
 
-        if (cell_playback->block_type == BLOCK_TYPE_ANGLE_BLOCK)
+        if (cell_playback->block_type == static_cast<unsigned int>(BLOCK_TYPE_ANGLE_BLOCK))
         {
             has_angles = true;
         }
@@ -301,7 +301,7 @@ static bool create_dvd_virtualfile(const ifo_handle_t *vts_file, const std::stri
     // Split file if chapter has several angles
     for (int angle_idx = 0; angle_idx < angles; angle_idx++)
     {
-        char title_buf[PATH_MAX + 1];
+        std::string title_buf;
         int angle_no        = angle_idx + 1;
 
         // can safely assume this a video
@@ -310,7 +310,7 @@ static bool create_dvd_virtualfile(const ifo_handle_t *vts_file, const std::stri
             // Single chapter
             if (angles > 1)
             {
-                snprintf(title_buf, sizeof(title_buf) - 1, "%02d. Chapter %03d (Angle %d) [%s].%s",
+                strsprintf(&title_buf, "%02d. Chapter %03d (Angle %d) [%s].%s",
                         title_no,
                         chapter_no,
                         angle_no,
@@ -319,7 +319,7 @@ static bool create_dvd_virtualfile(const ifo_handle_t *vts_file, const std::stri
             }
             else
             {
-                snprintf(title_buf, sizeof(title_buf) - 1, "%02d. Chapter %03d [%s].%s",
+                strsprintf(&title_buf, "%02d. Chapter %03d [%s].%s",
                         title_no,
                         chapter_no,
                         replace_all(format_duration(duration), ":", "-").c_str(),
@@ -331,7 +331,7 @@ static bool create_dvd_virtualfile(const ifo_handle_t *vts_file, const std::stri
             // Full title
             if (angles > 1)
             {
-                snprintf(title_buf, sizeof(title_buf) - 1, "%02d. Title (Angle %d) [%s].%s",
+                strsprintf(&title_buf, "%02d. Title (Angle %d) [%s].%s",
                         title_no,
                         angle_no,
                         replace_all(format_duration(duration), ":", "-").c_str(),
@@ -339,28 +339,26 @@ static bool create_dvd_virtualfile(const ifo_handle_t *vts_file, const std::stri
             }
             else
             {
-                snprintf(title_buf, sizeof(title_buf) - 1, "%02d. Title [%s].%s",
+                strsprintf(&title_buf, "%02d. Title [%s].%s",
                         title_no,
                         replace_all(format_duration(duration), ":", "-").c_str(),
                         ffmpeg_format[0].fileext().c_str());
             }
         }
 
-        std::string filename(title_buf);
-
         LPVIRTUALFILE virtualfile = nullptr;
         if (!ffmpeg_format[0].is_multiformat())
         {
-            virtualfile = insert_file(VIRTUALTYPE_DVD, path + filename, statbuf);
+            virtualfile = insert_file(VIRTUALTYPE_DVD, path + title_buf, statbuf);
         }
         else
         {
-            virtualfile = insert_dir(VIRTUALTYPE_DVD, path + filename, statbuf);
+            virtualfile = insert_dir(VIRTUALTYPE_DVD, path + title_buf, statbuf);
         }
 
         if (virtualfile == nullptr)
         {
-            Logging::error(path, "Failed to create virtual path: %1", (path + filename).c_str());
+            Logging::error(path, "Failed to create virtual path: %1", (path + title_buf).c_str());
             errno = EIO;
             return false;
         }
