@@ -1,5 +1,5 @@
-﻿/*
- * Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+/*
+ * Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
  * @ingroup ffmpegfs
  *
  * @author Norbert Schlia (nschlia@oblivion-software.de)
- * @copyright Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * @copyright Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  */
 
 #ifdef __cplusplus
@@ -56,10 +56,6 @@ FFmpeg_Base::FFmpeg_Base()
 {
 }
 
-FFmpeg_Base::~FFmpeg_Base()
-{
-}
-
 #if !LAVC_DEP_AV_INIT_PACKET
 void FFmpeg_Base::init_packet(AVPacket *pkt) const
 {
@@ -302,16 +298,16 @@ std::string FFmpeg_Base::get_sample_fmt_name(AVSampleFormat sample_fmt)
 #if LAVU_DEP_OLD_CHANNEL_LAYOUT
 std::string FFmpeg_Base::get_channel_layout_name(const AVChannelLayout * ch_layout)
 {
-    char buffer[1024];
-    av_channel_layout_describe(ch_layout, buffer, sizeof(buffer) - 1);
-    return buffer;
+    std::array<char, 1024> buffer;
+    av_channel_layout_describe(ch_layout, buffer.data(), buffer.size() - 1);
+    return buffer.data();
 }
 #else   // !LAVU_DEP_OLD_CHANNEL_LAYOUT
 std::string FFmpeg_Base::get_channel_layout_name(int nb_channels, uint64_t channel_layout)
 {
-    char buffer[1024];
-    av_get_channel_layout_string(buffer, sizeof(buffer) - 1, nb_channels, channel_layout);
-    return buffer;
+    std::array<char, 1024> buffer;
+    av_get_channel_layout_string(buffer.data(), buffer.size() - 1, nb_channels, channel_layout);
+    return buffer.data();
 }
 #endif  // !LAVU_DEP_OLD_CHANNEL_LAYOUT
 
@@ -437,7 +433,7 @@ int FFmpeg_Base::get_script_info(AVCodecContext *codec_ctx, int play_res_x, int
 
     size_t size = static_cast<size_t>(snprintf(nullptr, 0, format,  play_res_x, play_res_y, font, font_size,
                                                primary_color, secondary_color, outline_color, back_color,
-                                               -bold, -italic, -underline, border_style, alignment) + 1); // Extra space for '\0'
+                                               -bold, -italic, -underline, border_style, alignment)) + 1; // Extra space for '\0'
 
     codec_ctx->subtitle_header = reinterpret_cast<uint8_t *>(av_malloc(size + 1));
 
