@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017-2022 by Norbert Schlia (nschlia@oblivion-software.de)
+ * Copyright (C) 2017-2023 by Norbert Schlia (nschlia@oblivion-software.de)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
  * @ingroup ffmpegfs
  *
  * @author Norbert Schlia (nschlia@oblivion-software.de)
- * @copyright Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * @copyright Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  */
 
 #ifndef FFMPEG_TRANSCODER_H
@@ -84,7 +84,7 @@ protected:
         struct PRORES_FRAMERATE                                     /**< @brief List of ProRes frame rates */
         {
             int                 m_framerate;                        /**< @brief Frame rate */
-            int                 m_interleaved;                      /**< @brief Format is interleaved */
+            bool                m_interleaved;                      /**< @brief Format is interleaved */
         }                       m_framerate[MAX_PRORES_FRAMERATE];  /**< @brief Array of frame rates */
         /**
          * Bitrates in MB/s
@@ -95,7 +95,7 @@ protected:
          * 4: ProRes 4444 (no alpha)
          * 5: ProRes 4444 XQ (no alpha)
          */
-        int                     m_bitrate[6];                       /**< @brief Bitrate of this format */
+        std::array<int, 6>		m_bitrate;                       	/**< @brief Bitrates for this format */
     } PRORES_BITRATE, *LPPRORES_BITRATE;                            /**< @brief Pointer version of PRORES_BITRATE */
     typedef PRORES_BITRATE const * LPCPRORES_BITRATE;               /**< @brief Pointer to const version of PRORES_BITRATE */
 
@@ -114,7 +114,7 @@ protected:
         /**
          * @brief Close (reset) AVCodecContext pointer
          */
-        void close();
+        void reset();
 
     public:
         std::shared_ptr<AVCodecContext> m_codec_ctx;                /**< @brief AVCodecContext for this encoder stream */
@@ -228,7 +228,7 @@ public:
     /**
      * @brief Close transcoder, free all ressources.
      */
-    void                        close();
+    void                        closeio();
     /**
      * @brief Get last modification time of file.
      * @return Modification time (seconds since epoch)
@@ -236,7 +236,7 @@ public:
     time_t                      mtime() const;
     /**
      * @brief Get the file duration.
-     * @return Returns the file in AV_TIME_BASE units.
+     * @return Returns the duration of the file in AV_TIME_BASE units.
      */
     int64_t                     duration() const;
     /**
@@ -294,11 +294,11 @@ public:
      * @param[in] duration - File duration.
      * @param[in] width - Target video width.
      * @param[in] height- Target video height.
-     * @param[in] interleaved - 1 if target video is interleaved.
+     * @param[in] interleaved - True if target video is interleaved, false if not.
      * @param[in] framerate - Frame rate of target video.
      * @return On success, returns true; on failure, returns false.
      */
-    static bool                 video_size(size_t *filesize, AVCodecID codec_id, BITRATE bit_rate, int64_t duration, int width, int height, int interleaved, const AVRational & framerate);
+    static bool                 video_size(size_t *filesize, AVCodecID codec_id, BITRATE bit_rate, int64_t duration, int width, int height, bool interleaved, const AVRational & framerate);
     /**
      * @brief Predict overhead in file size. This may (better will surely) be inaccurate.
      * @param[out] filesize - Predicted file size in bytes, including overhead.
@@ -366,6 +366,12 @@ public:
      */
     int                         flush_delayed_subtitles();
 
+    /**
+     * @brief Get PTS (presentation time stamp) of decoded audio/video so far.
+     * @return Returns the PTS (presentation time stamp) of decoded audio/video so far in AV_TIME_BASE units.
+     */
+    int64_t                     pts() const;
+
 protected:
     /**
      * @brief Copy data from audio FIFO to frame buffer.
@@ -401,7 +407,7 @@ protected:
      * @todo Add text to bitmap conversion.
      * @return On success, returns 0; on error, a negative AVERROR value.
      */
-    int open_subtitles();
+    int                         open_subtitles();
     /**
      * @brief open_albumarts
      * @return On success, returns 0; on error, a negative AVERROR value.
@@ -460,10 +466,10 @@ protected:
     /**
      * @brief Prepare codec options.
      * @param[in] opt - Codec private data.
-     * @param[in] profile_option - Selected profile option.
+     * @param[in] profile_option_vec - Selected profile option.
      * @return On success, returns 0; on error, a negative AVERROR value.
      */
-    int                         update_codec(void *opt, LPCPROFILE_OPTION profile_option) const;
+    int                         update_codec(void *opt, const PROFILE_OPTION_VEC & profile_option_vec) const;
     /**
      * @brief Prepare codec options for a file type.
      * @param[in] opt - Codec private data.
@@ -559,10 +565,10 @@ protected:
     /**
      * @brief Update format options
      * @param[in] dict - Dictionary to update.
-     * @param[in] option - Profile option to set.
+     * @param[in] option_vec - Profile option to set.
      * @return On success, returns 0; on error, a negative AVERROR value.
      */
-    int                         update_format(AVDictionary** dict, LPCPROFILE_OPTION option) const;
+    int                         update_format(AVDictionary** dict, const PROFILE_OPTION_VEC & option_vec) const;
     /**
      * @brief Prepare format optimisations
      * @param[in] dict - Dictionary to update.
@@ -774,11 +780,11 @@ protected:
      * @param[in] width - Video width in pixels.
      * @param[in] height - Video height in pixels.
      * @param[in] framerate - Video frame rate.
-     * @param[in] interleaved - If 1, video is interleaved; 0 if not.
+     * @param[in] interleaved - If true, video is interleaved; false if not.
      * @param[in] profile - Selected ProRes profile.
      * @return Bitrate in bit/s.
      */
-    static BITRATE              get_prores_bitrate(int width, int height, const AVRational &framerate, int interleaved, int profile);
+    static BITRATE              get_prores_bitrate(int width, int height, const AVRational &framerate, bool interleaved, int profile);
     /**
      * @brief Try to predict final file size.
      */
@@ -1179,7 +1185,7 @@ protected:
      * @param[in] f - Funtion to be called for each file found
      * @return 0 on success, a negative AVERROR code on failure.
      */
-    int                         foreach_subtitle_file(const std::string& search_path, const std::regex& regex, int depth, std::function<int(const std::string &, const std::optional<std::string> &)> f);
+    int                         foreach_subtitle_file(const std::string& search_path, const std::regex& regex, int depth, const std::function<int (const std::string &, const std::optional<std::string> &)> & f);
 
 private:
     FileIO *                    m_fileio;                       /**< @brief FileIO object of input file */
@@ -1232,7 +1238,7 @@ private:
     uint32_t                    m_reset_pts;                    /**< @brief We have to reset audio/video pts to the new position */
     uint32_t                    m_fake_frame_no;                /**< @brief The MJEPG codec requires monotonically growing PTS values so we fake some to avoid them going backwards after seeks */
 
-    static const PRORES_BITRATE m_prores_bitrate[];             /**< @brief ProRes bitrate table. Used for file size prediction. */
+    static const std::vector<PRORES_BITRATE> m_prores_bitrate;	/**< @brief ProRes bitrate table. Used for file size prediction. */
 
     // Hardware acceleration
     static const DEVICETYPE_MAP m_devicetype_map;               /**< @brief List of AVPixelFormats mapped to hardware acceleration types */
