@@ -1,5 +1,5 @@
-﻿/*
- * Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+/*
+ * Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
  * @ingroup ffmpegfs
  *
  * @author Norbert Schlia (nschlia@oblivion-software.de)
- * @copyright Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * @copyright Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  */
 
 #ifdef __cplusplus
@@ -50,7 +50,6 @@ extern "C" {
 
 #include <iostream>
 #include <libgen.h>
-#include <unistd.h>
 #include <algorithm>
 #include <wordexp.h>
 #include <memory>
@@ -60,7 +59,6 @@ extern "C" {
 #include <codecvt>
 #include <vector>
 #include <cstring>
-#include <iterator>
 #include <functional>
 
 #include <iconv.h>
@@ -73,6 +71,8 @@ extern "C" {
 #pragma GCC diagnostic ignored "-Wpedantic"
 #include <chardet.h>
 #pragma GCC diagnostic pop
+#include <fnmatch.h>
+#include <unistd.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -127,14 +127,14 @@ Format_Options::Format_Options()
 }
 
 Format_Options::Format_Options(
-        const std::string & format_name,
-        const std::string & fileext,
-        const FORMAT_MAP &  format,
-        bool                albumart_supported
+        std::string format_name,
+        std::string fileext,
+        FORMAT_MAP  format,
+        bool        albumart_supported
         )
-    : m_format_name(format_name)
-    , m_fileext(fileext)
-    , m_format_map(format)
+    : m_format_name(std::move(format_name))
+    , m_fileext(std::move(fileext))
+    , m_format_map(std::move(format))
     , m_albumart_supported(albumart_supported)
 {
 
@@ -159,13 +159,12 @@ AVCodecID Format_Options::video_codec() const
 
 bool Format_Options::is_video_codec_supported(AVCodecID codec_id) const
 {
-    FORMAT_MAP::const_iterator it1 = m_format_map.find(params.m_sample_fmt);
-    if (it1 != m_format_map.cend())
+    FORMAT_MAP::const_iterator it = m_format_map.find(params.m_sample_fmt);
+    if (it != m_format_map.cend())
     {
-        const CODEC_VECT & video_codec = it1->second.m_video_codec;
-        for (typename CODEC_VECT::const_iterator it2 = video_codec.cbegin(); it2 != video_codec.cend(); ++it2)
+        for (const AVCodecID & video_codec : it->second.m_video_codec)
         {
-            if (*it2 == codec_id)
+            if (video_codec == codec_id)
             {
                 return true;
             }
@@ -177,18 +176,17 @@ bool Format_Options::is_video_codec_supported(AVCodecID codec_id) const
 std::string Format_Options::video_codec_list() const
 {
     std::string buffer;
-    FORMAT_MAP::const_iterator it1 = m_format_map.find(params.m_sample_fmt);
-    if (it1 != m_format_map.cend())
+    FORMAT_MAP::const_iterator it = m_format_map.find(params.m_sample_fmt);
+    if (it != m_format_map.cend())
     {
-        const CODEC_VECT & video_codec = it1->second.m_video_codec;
-        for (typename CODEC_VECT::const_iterator it2 = video_codec.cbegin(); it2 != video_codec.cend(); )
+        for (const AVCodecID & video_codec : it->second.m_video_codec)
         {
-            buffer += get_video_codec_text(*it2);
-
-            if (++it2 != video_codec.cend())
+            if (!buffer.empty())
             {
                 buffer += ", ";
             }
+
+            buffer += get_video_codec_text(video_codec);
         }
     }
 
@@ -214,13 +212,12 @@ AVCodecID Format_Options::audio_codec() const
 
 bool Format_Options::is_audio_codec_supported(AVCodecID codec_id) const
 {
-    FORMAT_MAP::const_iterator it1 = m_format_map.find(params.m_sample_fmt);
-    if (it1 != m_format_map.cend())
+    FORMAT_MAP::const_iterator it = m_format_map.find(params.m_sample_fmt);
+    if (it != m_format_map.cend())
     {
-        const CODEC_VECT & audio_codec = it1->second.m_audio_codec;
-        for (typename CODEC_VECT::const_iterator it2 = audio_codec.cbegin(); it2 != audio_codec.cend(); ++it2)
+        for (const AVCodecID & audio_codec : it->second.m_audio_codec)
         {
-            if (*it2 == codec_id)
+            if (audio_codec == codec_id)
             {
                 return true;
             }
@@ -232,18 +229,17 @@ bool Format_Options::is_audio_codec_supported(AVCodecID codec_id) const
 std::string Format_Options::audio_codec_list() const
 {
     std::string buffer;
-    FORMAT_MAP::const_iterator it1 = m_format_map.find(params.m_sample_fmt);
-    if (it1 != m_format_map.cend())
+    FORMAT_MAP::const_iterator it = m_format_map.find(params.m_sample_fmt);
+    if (it != m_format_map.cend())
     {
-        const CODEC_VECT & audio_codec = it1->second.m_audio_codec;
-        for (typename CODEC_VECT::const_iterator it2 = audio_codec.cbegin(); it2 != audio_codec.cend();)
+        for (const AVCodecID & audio_codec : it->second.m_audio_codec)
         {
-            buffer += get_audio_codec_text(*it2);
-
-            if (++it2 != audio_codec.cend())
+            if (!buffer.empty())
             {
                 buffer += ", ";
             }
+
+            buffer += get_audio_codec_text(audio_codec);
         }
     }
 
@@ -293,12 +289,12 @@ AVCodecID Format_Options::subtitle_codec(AVCodecID codec_id) const
     }
 
     // Try to find direct match, prefer same as input stream
-    for (CODEC_VECT::const_iterator it2 = it->second.m_subtitle_codec.cbegin(); it2 != it->second.m_subtitle_codec.cend(); ++it2)
+    for (const AVCodecID & subtitle_codec : it->second.m_subtitle_codec)
     {
         // Also match AV_CODEC_ID_DVD_SUBTITLE to AV_CODEC_ID_DVB_SUBTITLE
-        if (*it2 == codec_id || (codec_id == AV_CODEC_ID_DVD_SUBTITLE && *it2 == AV_CODEC_ID_DVB_SUBTITLE))
+        if (subtitle_codec == codec_id || (codec_id == AV_CODEC_ID_DVD_SUBTITLE && subtitle_codec == AV_CODEC_ID_DVB_SUBTITLE))
         {
-            return *it2;
+            return subtitle_codec;
         }
     }
 
@@ -306,22 +302,22 @@ AVCodecID Format_Options::subtitle_codec(AVCodecID codec_id) const
     if (is_text_codec(codec_id))
     {
         // Find a text based codec in the list
-        for (CODEC_VECT::const_iterator it2 = it->second.m_subtitle_codec.cbegin(); it2 != it->second.m_subtitle_codec.cend(); ++it2)
+        for (const AVCodecID & subtitle_codec : it->second.m_subtitle_codec)
         {
-            if (is_text_codec(*it2))
+            if (is_text_codec(subtitle_codec))
             {
-                return *it2;
+                return subtitle_codec;
             }
         }
     }
     else
     {
         // Find a bitmap based codec in the list
-        for (CODEC_VECT::const_iterator it2 = it->second.m_subtitle_codec.cbegin(); it2 != it->second.m_subtitle_codec.cend(); ++it2)
+        for (const AVCodecID & subtitle_codec : it->second.m_subtitle_codec)
         {
-            if (!is_text_codec(*it2))
+            if (!is_text_codec(subtitle_codec))
             {
-                return *it2;
+                return subtitle_codec;
             }
         }
     }
@@ -1057,11 +1053,6 @@ const std::string & remove_ext(std::string *filepath)
     return *filepath;
 }
 
-bool allow_list_ext(const std::string & ext)
-{
-    return (params.m_extensions->find(ext) != params.m_extensions->cend());
-}
-
 bool find_ext(std::string * ext, const std::string & filename)
 {
     size_t found;
@@ -1116,7 +1107,7 @@ const std::string & append_ext(std::string * filepath, const std::string & ext)
 
     found = filepath->rfind('.');
 
-    if (found == std::string::npos || strcasecmp(filepath->substr(found + 1), ext))
+    if (found == std::string::npos || strcasecmp(filepath->substr(found + 1), ext) != 0)
     {
         // No extension or different extension
         *filepath += '.' + ext;
@@ -1144,9 +1135,9 @@ std::string ffmpeg_geterror(int errnum)
 {
     if (errnum < 0)
     {
-        char error[AV_ERROR_MAX_STRING_SIZE];
-        av_strerror(errnum, error, AV_ERROR_MAX_STRING_SIZE);
-        return error;
+        std::array<char, AV_ERROR_MAX_STRING_SIZE + 1> error;
+        av_strerror(errnum, error.data(), error.size() - 1);
+        return error.data();
     }
     else
     {
@@ -1222,8 +1213,7 @@ static std::string ffmpeg_libinfo(bool lib_exists, __attribute__((unused)) unsig
 
     if (lib_exists)
     {
-        strsprintf(info,
-                   "lib%-17s: %d.%d.%d\n",
+        strsprintf(&info, "lib%-17s: %d.%d.%d\n",
                    libname,
                    version_minor,
                    version_major,
@@ -1503,7 +1493,8 @@ std::string format_number(int64_t value)
         return "unset";
     }
 
-    return strsprintf("%" PRId64, value);
+    std::string buffer;
+    return strsprintf(&buffer, "%" PRId64, value);
 }
 
 std::string format_bitrate(BITRATE value)
@@ -1515,15 +1506,18 @@ std::string format_bitrate(BITRATE value)
 
     if (value > 1000000)
     {
-        return strsprintf("%.2f Mbps", static_cast<double>(value) / 1000000);
+        std::string buffer;
+        return strsprintf(&buffer, "%.2f Mbps", static_cast<double>(value) / 1000000);
     }
     else if (value > 1000)
     {
-        return strsprintf("%.1f kbps", static_cast<double>(value) / 1000);
+        std::string buffer;
+        return strsprintf(&buffer, "%.1f kbps", static_cast<double>(value) / 1000);
     }
     else
     {
-        return strsprintf("%" PRId64 " bps", value);
+        std::string buffer;
+        return strsprintf(&buffer, "%" PRId64 " bps", value);
     }
 }
 
@@ -1536,11 +1530,13 @@ std::string format_samplerate(int value)
 
     if (value < 1000)
     {
-        return strsprintf("%u Hz", value);
+        std::string buffer;
+        return strsprintf(&buffer, "%u Hz", value);
     }
     else
     {
-        return strsprintf("%.3f kHz", static_cast<double>(value) / 1000);
+        std::string buffer;
+        return strsprintf(&buffer, "%.3f kHz", static_cast<double>(value) / 1000);
     }
 }
 
@@ -1555,22 +1551,23 @@ std::string format_duration(int64_t value, uint32_t fracs /*= 3*/)
     }
 
     std::string buffer;
+    std::string duration;
     unsigned hours   = static_cast<unsigned>((value / AV_TIME_BASE) / (3600));
     unsigned mins    = static_cast<unsigned>(((value / AV_TIME_BASE) % 3600) / 60);
     unsigned secs    = static_cast<unsigned>((value / AV_TIME_BASE) % 60);
 
     if (hours)
     {
-        buffer = strsprintf("%02u:", hours);
+        duration = strsprintf(&buffer, "%02u:", hours);
     }
 
-    buffer += strsprintf("%02u:%02u", mins, secs);
+    duration += strsprintf(&buffer, "%02u:%02u", mins, secs);
     if (fracs)
     {
         unsigned decimals    = static_cast<unsigned>(value % AV_TIME_BASE);
-        buffer += strsprintf(".%0*u", sizeof(X(AV_TIME_BASE)) - 2, decimals).substr(0, fracs + 1);
+        duration += strsprintf(&buffer, ".%0*u", sizeof(X(AV_TIME_BASE)) - 2, decimals).substr(0, fracs + 1);
     }
-    return buffer;
+    return duration;
 }
 
 std::string format_time(time_t value)
@@ -1586,6 +1583,7 @@ std::string format_time(time_t value)
     }
 
     std::string buffer;
+    std::string time;
     int weeks;
     int days;
     int hours;
@@ -1604,25 +1602,25 @@ std::string format_time(time_t value)
 
     if (weeks)
     {
-        buffer = strsprintf("%iw ", weeks);
+        time = strsprintf(&buffer, "%iw ", weeks);
     }
     if (days)
     {
-        buffer += strsprintf("%id ", days);
+        time += strsprintf(&buffer, "%id ", days);
     }
     if (hours)
     {
-        buffer += strsprintf("%ih ", hours);
+        time += strsprintf(&buffer, "%ih ", hours);
     }
     if (mins)
     {
-        buffer += strsprintf("%im ", mins);
+        time += strsprintf(&buffer, "%im ", mins);
     }
     if (secs)
     {
-        buffer += strsprintf("%is ", secs);
+        time += strsprintf(&buffer, "%is ", secs);
     }
-    return buffer;
+    return time;
 }
 
 std::string format_size(uint64_t value)
@@ -1639,29 +1637,35 @@ std::string format_size(uint64_t value)
 
     if (value > 1024*1024*1024*1024LL)
     {
-        return strsprintf("%.3f TB", static_cast<double>(value) / (1024*1024*1024*1024LL));
+        std::string buffer;
+        return strsprintf(&buffer, "%.3f TB", static_cast<double>(value) / (1024*1024*1024*1024LL));
     }
     else if (value > 1024*1024*1024)
     {
-        return strsprintf("%.2f GB", static_cast<double>(value) / (1024*1024*1024));
+        std::string buffer;
+        return strsprintf(&buffer, "%.2f GB", static_cast<double>(value) / (1024*1024*1024));
     }
     else if (value > 1024*1024)
     {
-        return strsprintf("%.1f MB", static_cast<double>(value) / (1024*1024));
+        std::string buffer;
+        return strsprintf(&buffer, "%.1f MB", static_cast<double>(value) / (1024*1024));
     }
     else if (value > 1024)
     {
-        return strsprintf("%.1f KB", static_cast<double>(value) / (1024));
+        std::string buffer;
+        return strsprintf(&buffer, "%.1f KB", static_cast<double>(value) / (1024));
     }
     else
     {
-        return strsprintf("%" PRIu64 " bytes", value);
+        std::string buffer;
+        return strsprintf(&buffer, "%" PRIu64 " bytes", value);
     }
 }
 
 std::string format_size_ex(uint64_t value)
 {
-    return format_size(value) + strsprintf(" (%" PRIu64 " bytes)", value);
+    std::string buffer;
+    return format_size(value) + strsprintf(&buffer, " (%" PRIu64 " bytes)", value);
 }
 
 std::string format_result_size(size_t size_resulting, size_t size_predicted)
@@ -1682,13 +1686,15 @@ std::string format_result_size_ex(size_t size_resulting, size_t size_predicted)
 {
     if (size_resulting >= size_predicted)
     {
+        std::string buffer;
         size_t value = size_resulting - size_predicted;
-        return format_size(value) + strsprintf(" (%zu bytes)", value);
+        return format_size(value) + strsprintf(&buffer, " (%zu bytes)", value);
     }
     else
     {
+        std::string buffer;
         size_t value = size_predicted - size_resulting;
-        return "-" + format_size(value) + strsprintf(" (-%zu bytes)", value);
+        return "-" + format_size(value) + strsprintf(&buffer, " (-%zu bytes)", value);
     }
 }
 
@@ -1772,11 +1778,11 @@ std::string fourcc_make_string(std::string * buf, uint32_t fourcc)
 
 void exepath(std::string * path)
 {
-    char result[PATH_MAX + 1] = "";
-    ssize_t count = readlink("/proc/self/exe", result, PATH_MAX);
+    std::array<char, PATH_MAX + 1> result;
+    ssize_t count = readlink("/proc/self/exe", result.data(), result.size() - 1);
     if (count != -1)
     {
-        *path = dirname(result);
+        *path = dirname(result.data());
         append_sep(path);
     }
     else
@@ -1787,13 +1793,13 @@ void exepath(std::string * path)
 
 std::string &ltrim(std::string &s)
 {
-    s.erase(s.begin(), std::find_if(s.begin(), s.end(), std::not_fn(std::ptr_fun<int, int>(std::isspace))));
+    s.erase(s.begin(), std::find_if(s.begin(), s.end(), std::not_fn(std::function<int(int)>(isspace))));
     return s;
 }
 
 std::string &rtrim(std::string &s)
 {
-    s.erase(std::find_if(s.rbegin(), s.rend(), std::not_fn(std::ptr_fun<int, int>(std::isspace))).base(), s.end());
+    s.erase(std::find_if(s.rbegin(), s.rend(), std::not_fn(std::function<int(int)>(isspace))).base(), s.end());
     return s;
 }
 
@@ -1820,7 +1826,12 @@ std::string replace_all(std::string *str, const std::string& from, const std::st
 
 bool replace_start(std::string *str, const std::string& from, const std::string& to)
 {
+#if __cplusplus >= 202002L
+    // C++20 (and later) code
+    if (str->starts_with(from) == 0)
+#else
     if (str->find(from, 0) == 0)
+#endif
     {
         str->replace(0, from.length(), to);
         return true;
@@ -1834,15 +1845,6 @@ int strcasecmp(const std::string & s1, const std::string & s2)
     return ::strcasecmp(s1.c_str(), s2.c_str());
 }
 
-template<typename ... Args>
-std::string strsprintf(const std::string& format, Args ... args)
-{
-    size_t size = static_cast<size_t>(snprintf(nullptr, 0, format.c_str(), args ...) + 1); // Extra space for '\0'
-    std::unique_ptr<char[]> buf(new(std::nothrow) char[size]);
-    std::snprintf(buf.get(), size, format.c_str(), args ...);
-    return std::string(buf.get(), buf.get() + size - 1); // We don't want the '\0' inside
-}
-
 int reg_compare(const std::string & value, const std::string & pattern, std::regex::flag_type flag)
 {
     int reti;
@@ -1968,15 +1970,15 @@ std::vector<std::string> split(const std::string& input, const std::string & reg
 
 std::string sanitise_filepath(std::string * filepath)
 {
-    char resolved_name[PATH_MAX + 1];
+    std::array<char, PATH_MAX + 1> resolved_name;
 
-    if (realpath(filepath->c_str(), resolved_name) != nullptr)
+    if (realpath(filepath->c_str(), resolved_name.data()) != nullptr)
     {
-        *filepath = resolved_name;
+        *filepath = resolved_name.data();
         return *filepath;
     }
 
-    // realpath has the strange feature to remove a traling slash if there.
+    // realpath has the strange feature to remove a trailing slash if there.
     // To mimick its behaviour, if realpath fails, at least remove it.
     std::string _filepath(*filepath);
     remove_sep(&_filepath);
@@ -2049,22 +2051,27 @@ size_t get_disk_free(std::string & path)
 
 bool check_ignore(size_t size, size_t offset)
 {
-    size_t blocksize[] = { 0x2000, 0x8000, 0x10000, 0 };
+    std::array<size_t, 3> blocksize_arr = { 0x2000, 0x8000, 0x10000 };
     bool ignore = false;
 
-    for (int n = 0; blocksize[n] && !ignore; n++)
+    for (const size_t & blocksize: blocksize_arr)
     {
         size_t rest;
         bool match;
 
-        match = !(offset % blocksize[n]);           // Must be multiple of block size
+        match = !(offset % blocksize);              // Must be multiple of block size
         if (!match)
         {
             continue;
         }
 
-        rest = size % offset;                       // Calculate rest. Cast OK, offset can never be < 0.
-        ignore = match && (rest < blocksize[n]);    // Ignore of rest is less than block size
+        rest = size % offset;                       // Calculate rest.
+        ignore = match && (rest < blocksize);       // Ignore of rest is less than block size
+
+        if (ignore)
+        {
+            break;
+        }
     }
 
     return ignore;
@@ -2072,7 +2079,8 @@ bool check_ignore(size_t size, size_t offset)
 
 std::string make_filename(uint32_t file_no, const std::string & fileext)
 {
-    return strsprintf("%06u.%s", file_no, fileext.c_str());
+    std::string buffer;
+    return strsprintf(&buffer, "%06u.%s", file_no, fileext.c_str());
 }
 
 bool file_exists(const std::string & filename)
@@ -2188,11 +2196,11 @@ int get_encoding (const char * str, std::string & encoding)
 
 int read_file(const std::string & path, std::string & result)
 {
-    const char UTF_8_BOM[3]     = { '\xEF', '\xBB', '\xBF' };
-    const char UTF_16_BE_BOM[2] = { '\xFE', '\xFF' };
-    const char UTF_16_LE_BOM[2] = { '\xFF', '\xFE' };
-    const char UTF_32_BE_BOM[4] = { '\x00', '\x00', '\xFE', '\xFF' };
-    const char UTF_32_LE_BOM[4] = { '\xFF', '\xFE', '\x00', '\x00' };
+    constexpr std::array<char, 3> UTF_8_BOM     = { '\xEF', '\xBB', '\xBF' };
+    constexpr std::array<char, 2> UTF_16_BE_BOM = { '\xFE', '\xFF' };
+    constexpr std::array<char, 2> UTF_16_LE_BOM = { '\xFF', '\xFE' };
+    constexpr std::array<char, 4> UTF_32_BE_BOM = { '\x00', '\x00', '\xFE', '\xFF' };
+    constexpr std::array<char, 4> UTF_32_LE_BOM = { '\xFF', '\xFE', '\x00', '\x00' };
 
     std::ifstream ifs;
     ENCODING encoding = ENCODING_ASCII;
@@ -2217,41 +2225,41 @@ int read_file(const std::string & path, std::string & result)
         }
 
         // Read the bottom mark
-        char BOM[4];
-        ifs.read((char*)&BOM, sizeof(BOM));
+        std::array<char, 4> BOM;
+        ifs.read(BOM.data(), BOM.size());
 
         // If you feel tempted to reorder these checks please note
         // that UTF_32_LE_BOM must be done before UTF_16_LE_BOM to
         // avoid misdetection :)
-        if (!memcmp(BOM, UTF_32_LE_BOM, sizeof(UTF_32_LE_BOM)))
+        if (!memcmp(BOM.data(), UTF_32_LE_BOM.data(), UTF_32_LE_BOM.size()))
         {
             // The file contains UTF-32LE BOM
             encoding = ENCODING_UTF32LE_BOM;
-            ifs.seekg(sizeof(UTF_32_LE_BOM));
+            ifs.seekg(UTF_32_LE_BOM.size());
         }
-        else if (!memcmp(BOM, UTF_32_BE_BOM, sizeof(UTF_32_BE_BOM)))
+        else if (!memcmp(BOM.data(), UTF_32_BE_BOM.data(), UTF_32_BE_BOM.size()))
         {
             // The file contains UTF-32BE BOM
             encoding = ENCODING_UTF32BE_BOM;
-            ifs.seekg(sizeof(UTF_32_BE_BOM));
+            ifs.seekg(UTF_32_BE_BOM.size());
         }
-        else if (!memcmp(BOM, UTF_16_LE_BOM, sizeof(UTF_16_LE_BOM)))
+        else if (!memcmp(BOM.data(), UTF_16_LE_BOM.data(), UTF_16_LE_BOM.size()))
         {
             // The file contains UTF-16LE BOM
             encoding = ENCODING_UTF16LE_BOM;
-            ifs.seekg(sizeof(UTF_16_LE_BOM));
+            ifs.seekg(UTF_16_LE_BOM.size());
         }
-        else if (!memcmp(BOM, UTF_16_BE_BOM, sizeof(UTF_16_BE_BOM)))
+        else if (!memcmp(BOM.data(), UTF_16_BE_BOM.data(), UTF_16_BE_BOM.size()))
         {
             // The file contains UTF-16BE BOM
             encoding = ENCODING_UTF16BE_BOM;
-            ifs.seekg(sizeof(UTF_16_BE_BOM));
+            ifs.seekg(UTF_16_BE_BOM.size());
         }
-        else if (!memcmp(BOM, UTF_8_BOM, sizeof(UTF_8_BOM)))
+        else if (!memcmp(BOM.data(), UTF_8_BOM.data(), UTF_8_BOM.size()))
         {
             // The file contains UTF-8 BOM
             encoding = ENCODING_UTF8_BOM;
-            ifs.seekg(sizeof(UTF_8_BOM));
+            ifs.seekg(UTF_8_BOM.size());
         }
         else
         {
@@ -2394,7 +2402,7 @@ void stat_set_size(struct stat *st, size_t size)
     st->st_blocks     = (st->st_size + 512 - 1) / 512;
 }
 
-bool detect_docker(void)
+bool detect_docker()
 {
     try
     {
@@ -2477,6 +2485,19 @@ const std::string & regex_escape(std::string * str)
     return *str;
 }
 
+bool is_selected(const std::string & ext)
+{
+    if (params.m_include_extensions->empty())
+    {
+        // If set is empty, allow all extensions
+        return true;
+    }
+
+    auto is_match = [ext](const std::string & regex_string) { return (fnmatch(regex_string.c_str(), ext.c_str(), 0) == 0); };
+
+    return (find_if(begin(*params.m_include_extensions), end(*params.m_include_extensions), is_match) != end(*params.m_include_extensions));
+}
+
 bool is_blocked(const std::string & filename)
 {
     std::string ext;
@@ -2487,23 +2508,24 @@ bool is_blocked(const std::string & filename)
     }
 
     // These are blocked by default, they confuse players like VLC or mpv which
-    // auto load them. As they get incorporated by FFmpegfs they would end up
-    // as duplicates.
+    // auto load them. As they get incorporated as subtitle tracks by FFmpegfs
+    // they would end up as duplicates.
     if (!strcasecmp(ext, "srt") || !strcasecmp(ext, "vtt"))
     {
         return true;
     }
 
+    auto is_match = [ext](const std::string & regex_string) { return (fnmatch(regex_string.c_str(), ext.c_str(), 0) == 0); };
+
     // Check block list
-    return (params.m_hide_extensions->find(ext) != params.m_hide_extensions->cend());
+    return (find_if(begin(*params.m_hide_extensions), end(*params.m_hide_extensions), is_match) != end(*params.m_hide_extensions));
 }
 
-std::string implode(const STRINGSET & s)
+void save_free(void **p)
 {
-    std::ostringstream stream;
-    std::copy(s.begin(), s.end(), std::ostream_iterator<std::string>(stream, ","));
-    std::string str(stream.str());
-    // Remove trailing ,
-    str.pop_back();
-    return str;
+    void * tmp = __atomic_exchange_n(p, nullptr, __ATOMIC_RELEASE);
+    if (tmp != nullptr)
+    {
+        free(tmp);
+    }
 }
