@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017-2022 by Norbert Schlia (nschlia@oblivion-software.de)
+ * Copyright (C) 2017-2023 by Norbert Schlia (nschlia@oblivion-software.de)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
  * @ingroup ffmpegfs
  *
  * @author Norbert Schlia (nschlia@oblivion-software.de)
- * @copyright Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * @copyright Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  */
 
 #ifndef FFMPEG_UTILS_H
@@ -44,7 +44,9 @@
 #define FFMPEFS_VERSION     PACKAGE_VERSION "-" EXTRA_VERSION   /**< @brief FFmpegfs version number */
 #endif
 
-#define __STDC_FORMAT_MACROS                                    /**< @brief Force PRId64 defines */
+#ifndef __STDC_FORMAT_MACROS
+#define __STDC_FORMAT_MACROS 1                                  /**< @brief Force PRId64 defines */
+#endif // !__STDC_FORMAT_MACROS
 
 #include "ffmpeg_compat.h"
 
@@ -52,9 +54,11 @@
 #include <vector>
 #include <regex>
 #include <set>
+#include <array>
+#include <iterator>
 
 #ifndef PATH_MAX
-#include <linux/limits.h>
+#include <climits>
 #endif
 
 #ifdef __cplusplus
@@ -145,9 +149,6 @@ const char *get_media_type_string(enum AVMediaType media_type);
 #define BITRATE int                                                                 /**< @brief For FFmpeg bit rate is an int. */
 #endif
 
-#define STRINGIFY(x) #x                                                             /**< @brief Stringification helper for STRINGIFY. Not to be used separately. */
-#define TOSTRING(x) STRINGIFY(x)                                                    /**< @brief Convert a macro argument into a string constant */
-
 #define SAFE_VALUE(p, v, d)     (((p) != nullptr) ? (p)->v : d)                     /**< @brief Access struct/class pointer safely, return default if nullptr */
 
 /**
@@ -294,11 +295,10 @@ public:
      * @param[in] format - Format options: Possible audio/video codecs and sample formats
      * @param[in] albumart_supported - true if album arts are supported (eg. mp3) or false if not (e.g. wav, aiff
      */
-    Format_Options(
-            const std::string & format_name,
-            const std::string & fileext,
-            const FORMAT_MAP &  format,
-            bool                albumart_supported
+    Format_Options(std::string format_name,
+            std::string fileext,
+            FORMAT_MAP format,
+            bool albumart_supported
             );
 
     /**
@@ -513,6 +513,8 @@ protected:
     FILETYPE                    m_filetype;         /**< @brief File type, MP3, MP4, OPUS etc. */
 };
 
+typedef std::array<FFmpegfs_Format, 2> FFMPEGFS_FORMAT_ARR;         /**< @brief Array of FFmpegfs formats. There are two, for audio and video */
+
 /**
  * @brief Add / to the path if required
  * @param[in] path - Path to add separator to.
@@ -550,12 +552,6 @@ const std::string & remove_path(std::string *filepath);
  * @return Returns constant reference to filename.
  */
 const std::string & remove_ext(std::string *filepath);
-/**
- * @brief Find extension in allowlist, if existing.
- * @param[in] ext - Extension, if found.
- * @return Returns true if extension was found, false if there was none
- */
-bool                allow_list_ext(const std::string & ext);
 /**
  * @brief Find extension in filename, if existing.
  * @param[in] ext - Extension, if found.
@@ -727,11 +723,21 @@ std::string         replace_all(std::string * str, const std::string& from, cons
 bool                replace_start(std::string *str, const std::string& from, const std::string& to = "");
 /**
  * @brief Format a std::string sprintf-like.
+ * @param[out] str - The pointer to std::string object where the resulting string is stored.
  * @param[in] format - sprintf-like format string.
  * @param[in] args - Arguments.
  * @return Returns the formatted string.
  */
-template<typename ... Args> std::string strsprintf(const std::string& format, Args ... args);
+template<typename ... Args>
+const std::string & strsprintf(std::string *str, const std::string & format, Args ... args)
+{
+    size_t size = static_cast<size_t>(snprintf(nullptr, 0, format.c_str(), args ...)) + 1; // Extra space for '\0'
+    std::unique_ptr<char[]> buf(new(std::nothrow) char[size]);
+    std::snprintf(buf.get(), size, format.c_str(), args ...);
+    str->clear();
+    str->insert(0, buf.get(), size - 1); // We don't want the '\0' inside
+    return *str;
+}
 /**
  * @brief strcasecmp() equivalent for std::string.
  * @param[in] s1 - std:string #1
@@ -819,7 +825,7 @@ int                 reg_compare(const std::string &value, const std::string &pat
  * @brief Expand path, e.g., expand ~/ to home directory.
  * @param[out] tgt - Expanded source path.
  * @param[in] src - Path to expand.
- * @return Omn success, returns expanded source path.
+ * @return On success, returns expanded source path.
  */
 const std::string & expand_path(std::string *tgt, const std::string &src);
 /**
@@ -1008,7 +1014,7 @@ void                stat_set_size(struct stat *st, size_t size);
  * @brief Detect if we are running under Docker.
  * @return Returns true, if running under Docker, or false if not.
  */
-bool                detect_docker(void);
+bool                detect_docker();
 
 /**
  * @brief Iterate through all elements in map and search for the passed element.
@@ -1054,6 +1060,12 @@ int                 get_audio_props(AVFormatContext *format_ctx, int *channels,
  */
 const std::string & regex_escape(std::string *str);
 
+/**
+ * @brief Find extension in include list, if existing.
+ * @param[in] ext - Extension, if found.
+ * @return Returns true if extension was found, false if there was none
+ */
+bool                is_selected(const std::string & ext);
 /**
  * @brief Check if filename should be hidden from output path
  * @param[in] filename - Name to check
@@ -1061,13 +1073,44 @@ const std::string & regex_escape(std::string *str);
  */
 bool                is_blocked(const std::string & filename);
 
-typedef std::set<std::string, comp> STRINGSET;                  /**< @brief Set of strings, sorted/search case insensitive */
+typedef std::vector<std::string> MATCHVEC;                     /**< @brief Array of strings, sorted/search case insensitive */
 
 /**
- * @brief Conbine set of strings into comma separated list.
+ * @brief Combine array of strings into comma separated list.
  * @param[in] s - std::set object to combine
  * @return List of strings, separated by commas.
  */
-std::string         implode(const STRINGSET & s);
+template<class T>
+std::string implode(const T &s)
+{
+    std::ostringstream stream;
+    std::copy(s.begin(), s.end(), std::ostream_iterator<std::string>(stream, ","));
+    std::string str(stream.str());
+    // Remove trailing ,
+    if (str.size())
+    {
+        str.pop_back();
+    }
+    return str;
+}
 
+/**
+ * @brief Savely delete memory: Pointer will be set to nullptr before deleted is actually called.
+ * @param[inout] p - Pointer to delete
+ */
+template<class T>
+void save_delete(T **p)
+{
+    T * tmp = __atomic_exchange_n(p, nullptr, __ATOMIC_RELEASE);
+    if (tmp != nullptr)
+    {
+        delete tmp;
+    }
+}
+
+/**
+ * @brief Savely free memory: Pointer will be set to nullptr before it is actually freed.
+ * @param[inout] p - Pointer to delete
+ */
+void save_free(void **p);
 #endif
