@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2006-2008 David Collett
  * Copyright (C) 2008-2012 K. Henriksson
- * Copyright (C) 2017-2022 FFmpeg support by Norbert Schlia (nschlia@oblivion-software.de)
+ * Copyright (C) 2017-2023 FFmpeg support by Norbert Schlia (nschlia@oblivion-software.de)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
  * @author Norbert Schlia (nschlia@oblivion-software.de)
  * @copyright Copyright (C) 2006-2008 David Collett @n
  * Copyright (C) 2008-2013 K. Henriksson @n
- * Copyright (C) 2017-2022 FFmpeg support by Norbert Schlia (nschlia@oblivion-software.de)
+ * Copyright (C) 2017-2023 FFmpeg support by Norbert Schlia (nschlia@oblivion-software.de)
  */
 
 #ifdef __cplusplus
@@ -54,7 +54,7 @@ extern "C" {
 #include <sys/sysinfo.h>
 #include <sqlite3.h>
 #include <unistd.h>
-
+#include <fnmatch.h>
 #include <iostream>
 
 #ifdef USE_LIBBLURAY
@@ -68,8 +68,8 @@ extern "C" {
 
 #include "ffmpeg_utils.h"
 
-FFmpegfs_Format ffmpeg_format[2];                       /**< @brief Two FFmpegfs_Format infos, 0: video file, 1: audio file */
-FFMPEGFS_PARAMS params;                                 /**< @brief FFmpegfs command line parameters */
+FFMPEGFS_FORMAT_ARR ffmpeg_format;                      /**< @brief Two FFmpegfs_Format infos, 0: video file, 1: audio file */
+FFMPEGFS_PARAMS     params;                             /**< @brief FFmpegfs command line parameters */
 
 FFMPEGFS_PARAMS::FFMPEGFS_PARAMS()
     : m_basepath("")                                    // required parameter
@@ -123,6 +123,7 @@ FFMPEGFS_PARAMS::FFMPEGFS_PARAMS()
     , m_expiry_time((60*60*24 /* d */) * 7)             // default: 1 week)
     , m_max_inactive_suspend(15)                        // default: 15 seconds
     , m_max_inactive_abort(30)                          // default: 30 seconds
+    , m_prebuffer_time(0)                               // default: no prebuffer time
     , m_prebuffer_size(100 /* KB */ * 1024)             // default: 100 KB
     , m_max_cache_size(0)                               // default: no limit
     , m_min_diskspace(0)                                // default: no minimum
@@ -135,8 +136,8 @@ FFMPEGFS_PARAMS::FFMPEGFS_PARAMS()
     , m_decoding_errors(0)                              // default: ignore errors
     , m_min_dvd_chapter_duration(1)                     // default: 1 second
     , m_oldnamescheme(0)                                // default: new scheme
-    , m_extensions(new STRINGSET)
-    , m_hide_extensions(new STRINGSET)
+    , m_include_extensions(new MATCHVEC)				// default: empty list
+    , m_hide_extensions(new MATCHVEC)                  	// default: empty list
     , m_win_smb_fix(1)                                  // default: fix enabled
 {
 }
@@ -149,87 +150,91 @@ FFMPEGFS_PARAMS::FFMPEGFS_PARAMS(const FFMPEGFS_PARAMS & other)
 FFMPEGFS_PARAMS::~FFMPEGFS_PARAMS()
 {
     delete m_hwaccel_dec_blocked;
-    delete m_extensions;
+    delete m_include_extensions;
     delete m_hide_extensions;
 }
 
 FFMPEGFS_PARAMS& FFMPEGFS_PARAMS::operator=(const FFMPEGFS_PARAMS & other) noexcept
 {
-    m_basepath = other.m_basepath;
-    m_mountpath = other.m_mountpath;
+    if (this != &other) // Self assignment check
+    {
+        m_basepath = other.m_basepath;
+        m_mountpath = other.m_mountpath;
 
-    m_audio_codec = other.m_audio_codec;
-    m_video_codec = other.m_video_codec;
+        m_audio_codec = other.m_audio_codec;
+        m_video_codec = other.m_video_codec;
 
-    m_autocopy = other.m_autocopy;
-    m_recodesame = other.m_recodesame;
-    m_profile = other.m_profile;
-    m_level = other.m_level;
+        m_autocopy = other.m_autocopy;
+        m_recodesame = other.m_recodesame;
+        m_profile = other.m_profile;
+        m_level = other.m_level;
 
-    m_audiobitrate = other.m_audiobitrate;
-    m_audiosamplerate = other.m_audiosamplerate;
-    m_audiochannels = other.m_audiochannels;
-    m_sample_fmt = other.m_sample_fmt;
+        m_audiobitrate = other.m_audiobitrate;
+        m_audiosamplerate = other.m_audiosamplerate;
+        m_audiochannels = other.m_audiochannels;
+        m_sample_fmt = other.m_sample_fmt;
 
-    m_videobitrate = other.m_videobitrate;
-    m_videowidth = other.m_videowidth;
-    m_videoheight = other.m_videoheight;
-    m_deinterlace = other.m_deinterlace;
-    m_segment_duration = other.m_segment_duration;
-    m_min_seek_time_diff = other.m_min_seek_time_diff;
+        m_videobitrate = other.m_videobitrate;
+        m_videowidth = other.m_videowidth;
+        m_videoheight = other.m_videoheight;
+        m_deinterlace = other.m_deinterlace;
+        m_segment_duration = other.m_segment_duration;
+        m_min_seek_time_diff = other.m_min_seek_time_diff;
 
-    m_hwaccel_enc_API = other.m_hwaccel_enc_API;
-    m_hwaccel_enc_device_type = other.m_hwaccel_enc_device_type;
-    m_hwaccel_enc_device = other.m_hwaccel_enc_device;
-    m_hwaccel_dec_API = other.m_hwaccel_dec_API;
-    m_hwaccel_dec_device_type = other.m_hwaccel_dec_device_type;
-    m_hwaccel_dec_device = other.m_hwaccel_dec_device;
-    m_hwaccel_dec_blocked = other.m_hwaccel_dec_blocked;
+        m_hwaccel_enc_API = other.m_hwaccel_enc_API;
+        m_hwaccel_enc_device_type = other.m_hwaccel_enc_device_type;
+        m_hwaccel_enc_device = other.m_hwaccel_enc_device;
+        m_hwaccel_dec_API = other.m_hwaccel_dec_API;
+        m_hwaccel_dec_device_type = other.m_hwaccel_dec_device_type;
+        m_hwaccel_dec_device = other.m_hwaccel_dec_device;
+        m_hwaccel_dec_blocked = other.m_hwaccel_dec_blocked;
 
-    m_no_subtitles = other.m_no_subtitles;
+        m_no_subtitles = other.m_no_subtitles;
 
-    m_noalbumarts = other.m_noalbumarts;
+        m_noalbumarts = other.m_noalbumarts;
 
-    m_enablescript = other.m_enablescript;
-    m_scriptfile = other.m_scriptfile;
-    m_scriptsource = other.m_scriptsource;
+        m_enablescript = other.m_enablescript;
+        m_scriptfile = other.m_scriptfile;
+        m_scriptsource = other.m_scriptsource;
 
-    m_debug = other.m_debug;
-    m_log_maxlevel = other.m_log_maxlevel;
-    m_log_stderr = other.m_log_stderr;
-    m_log_syslog = other.m_log_syslog;
-    m_logfile = other.m_logfile;
+        m_debug = other.m_debug;
+        m_log_maxlevel = other.m_log_maxlevel;
+        m_log_stderr = other.m_log_stderr;
+        m_log_syslog = other.m_log_syslog;
+        m_logfile = other.m_logfile;
 
-    m_expiry_time = other.m_expiry_time;
-    m_max_inactive_suspend = other.m_max_inactive_suspend;
-    m_max_inactive_abort = other.m_max_inactive_abort;
-    m_prebuffer_size = other.m_prebuffer_size;
-    m_max_cache_size = other.m_max_cache_size;
-    m_min_diskspace = other.m_min_diskspace;
-    m_cachepath = other.m_cachepath;
-    m_disable_cache = other.m_disable_cache;
-    m_cache_maintenance = other.m_cache_maintenance;
-    m_prune_cache = other.m_prune_cache;
-    m_clear_cache = other.m_clear_cache;
-    m_max_threads = other.m_max_threads;
-    m_decoding_errors = other.m_decoding_errors;
-    m_min_dvd_chapter_duration = other.m_min_dvd_chapter_duration;
-    m_oldnamescheme = other.m_oldnamescheme;
-    *m_extensions = *other.m_extensions;
-    *m_hide_extensions = *other.m_hide_extensions;
-    m_win_smb_fix = other.m_win_smb_fix;
+        m_expiry_time = other.m_expiry_time;
+        m_max_inactive_suspend = other.m_max_inactive_suspend;
+        m_max_inactive_abort = other.m_max_inactive_abort;
+        m_prebuffer_time = other.m_prebuffer_time;
+        m_prebuffer_size = other.m_prebuffer_size;
+        m_max_cache_size = other.m_max_cache_size;
+        m_min_diskspace = other.m_min_diskspace;
+        m_cachepath = other.m_cachepath;
+        m_disable_cache = other.m_disable_cache;
+        m_cache_maintenance = other.m_cache_maintenance;
+        m_prune_cache = other.m_prune_cache;
+        m_clear_cache = other.m_clear_cache;
+        m_max_threads = other.m_max_threads;
+        m_decoding_errors = other.m_decoding_errors;
+        m_min_dvd_chapter_duration = other.m_min_dvd_chapter_duration;
+        m_oldnamescheme = other.m_oldnamescheme;
+        *m_include_extensions = *other.m_include_extensions;
+        *m_hide_extensions = *other.m_hide_extensions;
+        m_win_smb_fix = other.m_win_smb_fix;
+    }
 
     return *this;
 }
 
-bool FFMPEGFS_PARAMS::smart_transcode(void) const
+bool FFMPEGFS_PARAMS::smart_transcode() const
 {
     return (ffmpeg_format[1].filetype() != FILETYPE_UNKNOWN && ffmpeg_format[0].filetype() != ffmpeg_format[1].filetype());
 }
 
 const FFmpegfs_Format *FFMPEGFS_PARAMS::current_format(LPCVIRTUALFILE virtualfile) const
 {
-    if (virtualfile == nullptr || virtualfile->m_format_idx < 0 || virtualfile->m_format_idx > 1)
+    if (virtualfile == nullptr || virtualfile->m_format_idx > 1)
     {
         return nullptr;
     }
@@ -250,7 +255,6 @@ enum
     KEY_AUDIO_SAMPLERATE,
     KEY_AUDIO_CHANNELS,
     KEY_AUDIO_SAMPLE_FMT,
-    KEY_EXTENSIONS,
     KEY_VIDEO_BITRATE,
     KEY_SEGMENT_DURATION,
     KEY_MIN_SEEK_TIME_DIFF,
@@ -259,6 +263,7 @@ enum
     KEY_EXPIRY_TIME,
     KEY_MAX_INACTIVE_SUSPEND_TIME,
     KEY_MAX_INACTIVE_ABORT_TIME,
+    KEY_PREBUFFER_TIME,
     KEY_PREBUFFER_SIZE,
     KEY_MAX_CACHE_SIZE,
     KEY_MIN_DISKSPACE_SIZE,
@@ -275,6 +280,7 @@ enum
     KEY_HWACCEL_DECODER_API,
     KEY_HWACCEL_DECODER_DEVICE,
     KEY_HWACCEL_DECODER_BLOCKED,
+    KEY_INCLUDE_EXTENSIONS,
     KEY_HIDE_EXTENSIONS
 };
 
@@ -285,8 +291,13 @@ enum
 
 /**
  * FUSE option descriptions
+ *
+ * Need to ignore annoying warnings caused by fuse.h
  */
-static struct fuse_opt ffmpegfs_opts[] =
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wnarrowing"
+#pragma GCC diagnostic ignored "-Wsign-conversion"
+static struct fuse_opt ffmpegfs_opts[] =    // NOLINT(modernize-avoid-c-arrays)
 {
     // Output type
     FUSE_OPT_KEY("--desttype=%s",                   KEY_DESTTYPE),
@@ -313,8 +324,6 @@ static struct fuse_opt ffmpegfs_opts[] =
     FUSE_OPT_KEY("audiochannels=%s",                KEY_AUDIO_CHANNELS),
     FUSE_OPT_KEY("--audiosamplefmt=%s",             KEY_AUDIO_SAMPLE_FMT),
     FUSE_OPT_KEY("audiosamplefmt=%s",               KEY_AUDIO_SAMPLE_FMT),
-    FUSE_OPT_KEY("--extensions=%s",                 KEY_EXTENSIONS),
-    FUSE_OPT_KEY("extensions=%s",                   KEY_EXTENSIONS),
     // Video
     FUSE_OPT_KEY("--videobitrate=%s",               KEY_VIDEO_BITRATE),
     FUSE_OPT_KEY("videobitrate=%s",                 KEY_VIDEO_BITRATE),
@@ -361,6 +370,8 @@ static struct fuse_opt ffmpegfs_opts[] =
     FUSE_OPT_KEY("max_inactive_suspend=%s",         KEY_MAX_INACTIVE_SUSPEND_TIME),
     FUSE_OPT_KEY("--max_inactive_abort=%s",         KEY_MAX_INACTIVE_ABORT_TIME),
     FUSE_OPT_KEY("max_inactive_abort=%s",           KEY_MAX_INACTIVE_ABORT_TIME),
+    FUSE_OPT_KEY("--prebuffer_time=%s",             KEY_PREBUFFER_TIME),
+    FUSE_OPT_KEY("prebuffer_time=%s",               KEY_PREBUFFER_TIME),
     FUSE_OPT_KEY("--prebuffer_size=%s",             KEY_PREBUFFER_SIZE),
     FUSE_OPT_KEY("prebuffer_size=%s",               KEY_PREBUFFER_SIZE),
     FUSE_OPT_KEY("--max_cache_size=%s",             KEY_MAX_CACHE_SIZE),
@@ -386,6 +397,8 @@ static struct fuse_opt ffmpegfs_opts[] =
     FFMPEGFS_OPT("min_dvd_chapter_duration=%u",     m_min_dvd_chapter_duration, 0),
     FFMPEGFS_OPT("--oldnamescheme=%u",              m_oldnamescheme, 0),
     FFMPEGFS_OPT("oldnamescheme=%u",                m_oldnamescheme, 0),
+    FUSE_OPT_KEY("--include_extensions=%s",         KEY_INCLUDE_EXTENSIONS),
+    FUSE_OPT_KEY("include_extensions=%s",           KEY_INCLUDE_EXTENSIONS),
     FUSE_OPT_KEY("--hide_extensions=%u",            KEY_HIDE_EXTENSIONS),
     FUSE_OPT_KEY("hide_extensions=%u",              KEY_HIDE_EXTENSIONS),
     // Experimental
@@ -413,6 +426,7 @@ static struct fuse_opt ffmpegfs_opts[] =
     FUSE_OPT_KEY("debug",                           KEY_KEEP_OPT),
     FUSE_OPT_END
 };
+#pragma GCC diagnostic pop
 
 typedef std::map<const std::string, const AUTOCOPY, comp> AUTOCOPY_MAP;         /**< @brief Map command line option to AUTOCOPY enum */
 typedef std::map<const std::string, const PROFILE, comp> PROFILE_MAP;           /**< @brief Map command line option to PROFILE enum */
@@ -609,7 +623,7 @@ static int          get_samplerate(const std::string & arg, int * samplerate);
 static int          get_sampleformat(const std::string & arg, SAMPLE_FMT * sample_fmt);
 static int          get_time(const std::string & arg, time_t *time);
 static int          get_size(const std::string & arg, size_t *size);
-static int          get_desttype(const std::string & arg, FFmpegfs_Format format[2]);
+static int          get_desttype(const std::string & arg, FFMPEGFS_FORMAT_ARR & format);
 static int          get_audiocodec(const std::string & arg, AVCodecID *audio_codec);
 static int          get_videocodec(const std::string & arg, AVCodecID *video_codec);
 static int          get_autocopy(const std::string & arg, AUTOCOPY *autocopy);
@@ -623,14 +637,14 @@ static int          get_codec(const std::string & codec, AVCodecID *codec_id);
 static int          get_hwaccel_dec_blocked(const std::string & arg, HWACCEL_BLOCKED_MAP **hwaccel_dec_blocked);
 static int          get_value(const std::string & arg, int *value);
 static int          get_value(const std::string & arg, std::string *value);
-static int          get_value(const std::string & arg, STRINGSET *value);
+static int          get_value(const std::string & arg, MATCHVEC *value);
 //static int          get_value(const std::string & arg, std::optional<std::string> *value);
 static int          get_value(const std::string & arg, double *value);
 
-static int          ffmpegfs_opt_proc(void* data, const char* arg, int key, struct fuse_args *outargs);
-static bool         set_defaults(void);
-static void         build_device_type_list(void);
-static void         print_params(void);
+static int          ffmpegfs_opt_proc(__attribute__((unused)) void* data, const char* arg, int key, struct fuse_args *outargs);
+static bool         set_defaults();
+static void         build_device_type_list();
+static void         print_params();
 static void         usage();
 
 /**
@@ -707,7 +721,7 @@ static int get_bitrate(const std::string & arg, BITRATE *bitrate)
         }
         else if (!reti)
         {
-            *bitrate = static_cast<BITRATE>(atol(data.c_str()));
+            *bitrate = static_cast<BITRATE>(std::stol(data));
             return 0;   // OK
         }
 
@@ -720,7 +734,7 @@ static int get_bitrate(const std::string & arg, BITRATE *bitrate)
         }
         else if (!reti)
         {
-            *bitrate = static_cast<BITRATE>(atof(data.c_str()) * 1000);
+            *bitrate = static_cast<BITRATE>(std::stof(data) * 1000);
             return 0;   // OK
         }
 
@@ -733,7 +747,7 @@ static int get_bitrate(const std::string & arg, BITRATE *bitrate)
         }
         else if (!reti)
         {
-            *bitrate = static_cast<BITRATE>(atof(data.c_str()) * 1000000);
+            *bitrate = static_cast<BITRATE>(std::stof(data) * 1000000);
             return 0;   // OK
         }
 
@@ -775,7 +789,7 @@ static int get_samplerate(const std::string & arg, int * samplerate)
         }
         else if (!reti)
         {
-            *samplerate = atoi(data.c_str());
+            *samplerate = std::stoi(data);
             return 0;   // OK
         }
 
@@ -788,7 +802,7 @@ static int get_samplerate(const std::string & arg, int * samplerate)
         }
         else if (!reti)
         {
-            *samplerate = static_cast<int>(atof(data.c_str()) * 1000);
+            *samplerate = static_cast<int>(std::stof(data) * 1000);
             return 0;   // OK
         }
 
@@ -885,7 +899,7 @@ static int get_time(const std::string & arg, time_t *time)
         }
         else if (!reti)
         {
-            *time = static_cast<time_t>(atol(data.c_str()));
+            *time = static_cast<time_t>(std::stol(data));
             return 0;   // OK
         }
 
@@ -898,7 +912,7 @@ static int get_time(const std::string & arg, time_t *time)
         }
         else if (!reti)
         {
-            *time = static_cast<time_t>(atof(data.c_str()) * 60);
+            *time = static_cast<time_t>(std::stof(data) * 60);
             return 0;   // OK
         }
 
@@ -911,7 +925,7 @@ static int get_time(const std::string & arg, time_t *time)
         }
         else if (!reti)
         {
-            *time = static_cast<time_t>(atof(data.c_str()) * 60 * 60);
+            *time = static_cast<time_t>(std::stof(data) * 60 * 60);
             return 0;   // OK
         }
 
@@ -924,7 +938,7 @@ static int get_time(const std::string & arg, time_t *time)
         }
         else if (!reti)
         {
-            *time = static_cast<time_t>(atof(data.c_str()) * 60 * 60 * 24);
+            *time = static_cast<time_t>(std::stof(data) * 60 * 60 * 24);
             return 0;   // OK
         }
 
@@ -937,7 +951,7 @@ static int get_time(const std::string & arg, time_t *time)
         }
         else if (!reti)
         {
-            *time = static_cast<time_t>(atof(data.c_str()) * 60 * 60 * 24 * 7);
+            *time = static_cast<time_t>(std::stof(data) * 60 * 60 * 24 * 7);
             return 0;   // OK
         }
 
@@ -984,7 +998,7 @@ static int get_size(const std::string & arg, size_t *size)
         }
         else if (!reti)
         {
-            *size = static_cast<size_t>(atol(data.c_str()));
+            *size = static_cast<size_t>(std::stol(data));
             return 0;   // OK
         }
 
@@ -997,7 +1011,7 @@ static int get_size(const std::string & arg, size_t *size)
         }
         else if (!reti)
         {
-            *size = static_cast<size_t>(atof(data.c_str()) * 1024);
+            *size = static_cast<size_t>(std::stof(data) * 1024);
             return 0;   // OK
         }
 
@@ -1010,7 +1024,7 @@ static int get_size(const std::string & arg, size_t *size)
         }
         else if (!reti)
         {
-            *size = static_cast<size_t>(atof(data.c_str()) * 1024 * 1024);
+            *size = static_cast<size_t>(std::stof(data) * 1024 * 1024);
             return 0;   // OK
         }
 
@@ -1023,7 +1037,7 @@ static int get_size(const std::string & arg, size_t *size)
         }
         else if (!reti)
         {
-            *size = static_cast<size_t>(atof(data.c_str()) * 1024 * 1024 * 1024);
+            *size = static_cast<size_t>(std::stof(data) * 1024 * 1024 * 1024);
             return 0;   // OK
         }
 
@@ -1036,7 +1050,7 @@ static int get_size(const std::string & arg, size_t *size)
         }
         else if (!reti)
         {
-            *size = static_cast<size_t>(atof(data.c_str()) * 1024 * 1024 * 1024 * 1024);
+            *size = static_cast<size_t>(std::stof(data) * 1024 * 1024 * 1024 * 1024);
             return 0;   // OK
         }
 
@@ -1057,7 +1071,7 @@ static int get_size(const std::string & arg, size_t *size)
  * Index 1: Selected audio format.
  * @return Returns 0 if found; if not found returns -1.
  */
-static int get_desttype(const std::string & arg, FFmpegfs_Format format[2])
+static int get_desttype(const std::string & arg, FFMPEGFS_FORMAT_ARR & format)
 {
     size_t pos = arg.find('=');
 
@@ -1549,7 +1563,7 @@ static int get_hwaccel_dec_blocked(const std::string & arg, HWACCEL_BLOCKED_MAP
         {
             nProfilesFound++;
             // Block codec and profile
-            (*hwaccel_dec_blocked)->insert(std::pair<AVCodecID, int>(codec_id, std::atoi(profile.c_str())));
+            (*hwaccel_dec_blocked)->insert(std::pair<AVCodecID, int>(codec_id, std::stoi(profile)));
         }
 
         if (!nProfilesFound)
@@ -1612,7 +1626,7 @@ static int get_value(const std::string & arg, int *value)
 
     if (pos != std::string::npos)
     {
-        *value = atoi(arg.substr(pos + 1).c_str());
+        *value = std::stoi(arg.substr(pos + 1));
 
         return 0;
     }
@@ -1652,7 +1666,7 @@ static int get_value(const std::string & arg, std::string *value)
  * @param[in] value - Upon return, contains a set of the values after the "=" sign.
  * @return Returns 0 if valid; if invalid returns -1.
  */
-static int get_value(const std::string & arg, STRINGSET *value)
+static int get_value(const std::string & arg, MATCHVEC *value)
 {
     size_t pos = arg.find('=');
 
@@ -1660,8 +1674,19 @@ static int get_value(const std::string & arg, STRINGSET *value)
     {
         std::vector<std::string> v = split(arg.substr(pos + 1), ",");
 
-        value->clear();
-        value->insert(v.begin(), v.end());
+        for (const std::string & str : v)
+        {
+            int res = fnmatch(str.c_str(), "", 0);
+
+            if (res != 0 && res != FNM_NOMATCH)
+            {
+                std::fprintf(stderr, "INVALID PARAMETER (%s): Error in wildcard pattern\n", str.c_str());
+
+                return -1;
+            }
+        }
+
+        value->insert(value->end(), v.begin(), v.end());
 
         return 0;
     }
@@ -1709,7 +1734,7 @@ static int get_value(const std::string & arg, double *value)
 
     if (pos != std::string::npos)
     {
-        *value = atof(arg.substr(pos + 1).c_str());
+        *value = std::stof(arg.substr(pos + 1));
 
         return 0;
     }
@@ -1727,10 +1752,8 @@ static int get_value(const std::string & arg, double *value)
  * @param[in] outargs - the current output argument list
  * @return -1 on error, 0 if arg is to be discarded, 1 if arg should be kept
  */
-static int ffmpegfs_opt_proc(void* data, const char* arg, int key, struct fuse_args *outargs)
+static int ffmpegfs_opt_proc(__attribute__((unused)) void* data, const char* arg, int key, struct fuse_args *outargs)
 {
-    (void)data;
-
     switch (key)
     {
     case FUSE_OPT_KEY_NONOPT:
@@ -1820,7 +1843,7 @@ static int ffmpegfs_opt_proc(void* data, const char* arg, int key, struct fuse_a
         std::printf("%-20s: %s\n", PACKAGE_NAME " Version", FFMPEFS_VERSION);
         std::printf("%s", ffmpeg_libinfo().c_str());
 
-        std::printf("\nFFMpeg capabilities\n\n");
+        std::printf("\nFFMpeg Capabilities\n\n");
 
         show_caps(0);
 
@@ -1870,10 +1893,6 @@ static int ffmpegfs_opt_proc(void* data, const char* arg, int key, struct fuse_a
     {
         return get_sampleformat(arg, &params.m_sample_fmt);
     }
-    case KEY_EXTENSIONS:
-    {
-        return get_value(arg, params.m_extensions);
-    }
     case KEY_SCRIPTFILE:
     {
         return get_value(arg, &params.m_scriptfile);
@@ -1926,6 +1945,10 @@ static int ffmpegfs_opt_proc(void* data, const char* arg, int key, struct fuse_a
     {
         return get_time(arg, &params.m_max_inactive_abort);
     }
+    case KEY_PREBUFFER_TIME:
+    {
+        return get_time(arg, &params.m_prebuffer_time);
+    }
     case KEY_PREBUFFER_SIZE:
     {
         return get_size(arg, &params.m_prebuffer_size);
@@ -1965,6 +1988,10 @@ static int ffmpegfs_opt_proc(void* data, const char* arg, int key, struct fuse_a
 
         return 0;
     }
+    case KEY_INCLUDE_EXTENSIONS:
+    {
+        return get_value(arg, params.m_include_extensions);
+    }
     case KEY_HIDE_EXTENSIONS:
     {
         return get_value(arg, params.m_hide_extensions);
@@ -1978,7 +2005,7 @@ static int ffmpegfs_opt_proc(void* data, const char* arg, int key, struct fuse_a
  * @brief Set default values.
  * @return Returns true if options are OK, false if option combination is invalid.
  */
-static bool set_defaults(void)
+static bool set_defaults()
 {
     if (ffmpeg_format[0].video_codec() == AV_CODEC_ID_PRORES)
     {
@@ -1996,7 +2023,7 @@ static bool set_defaults(void)
  * Builds a list of device types supported by the current
  * FFmpeg libary.
  */
-static void build_device_type_list(void)
+static void build_device_type_list()
 {
     for (AVHWDeviceType device_type = AV_HWDEVICE_TYPE_NONE; (device_type = av_hwdevice_iterate_types(device_type)) != AV_HWDEVICE_TYPE_NONE;)
     {
@@ -2014,7 +2041,7 @@ static void build_device_type_list(void)
 /**
  * @brief Print currently selected parameters.
  */
-static void print_params(void)
+static void print_params()
 {
     std::string cachepath;
 
@@ -2058,7 +2085,7 @@ static void print_params(void)
     Logging::trace(nullptr, "Recode to same fmt: %1", get_recodesame_text(params.m_recodesame).c_str());
     Logging::trace(nullptr, "Profile           : %1", get_profile_text(params.m_profile).c_str());
     Logging::trace(nullptr, "Level             : %1", get_level_text(params.m_level).c_str());
-    Logging::trace(nullptr, "Extra Extensions  : %1", implode(*params.m_extensions).c_str());
+    Logging::trace(nullptr, "Include Extensions: %1", implode(*params.m_include_extensions).c_str());
     Logging::trace(nullptr, "Hide Extensions   : %1", implode(*params.m_hide_extensions).c_str());
     Logging::trace(nullptr, "--------- Audio ---------");
     Logging::trace(nullptr, "Codecs            : %1+%2", get_codec_name(ffmpeg_format[0].audio_codec(), true), get_codec_name(ffmpeg_format[1].audio_codec(), true));
@@ -2101,7 +2128,8 @@ static void print_params(void)
     Logging::trace(nullptr, "Expiry Time       : %1", format_time(params.m_expiry_time).c_str());
     Logging::trace(nullptr, "Inactivity Suspend: %1", format_time(params.m_max_inactive_suspend).c_str());
     Logging::trace(nullptr, "Inactivity Abort  : %1", format_time(params.m_max_inactive_abort).c_str());
-    Logging::trace(nullptr, "Pre-buffer size   : %1", format_size(params.m_prebuffer_size).c_str());
+    Logging::trace(nullptr, "Pre-buffer Time   : %1", format_time(params.m_prebuffer_time).c_str());
+    Logging::trace(nullptr, "Pre-buffer Size   : %1", format_size(params.m_prebuffer_size).c_str());
     Logging::trace(nullptr, "Max. Cache Size   : %1", format_size(params.m_max_cache_size).c_str());
     Logging::trace(nullptr, "Min. Disk Space   : %1", format_size(params.m_min_diskspace).c_str());
     Logging::trace(nullptr, "Cache Path        : %1", cachepath.c_str());
@@ -2135,7 +2163,7 @@ int main(int argc, char *argv[])
     if (getppid() == getpgid(0))
     {
         std::printf("%s V%s\n", PACKAGE_NAME, FFMPEFS_VERSION);
-        std::printf("Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)\n"
+        std::printf("Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)\n"
                     "David Collett (2006-2008) and K. Henriksson (2008-2012)\n\n");
     }
 
@@ -2245,32 +2273,32 @@ int main(int argc, char *argv[])
     }
 
     // Check if sample format is supported
-    for (size_t n = 0; n < 2; n++)
+    for (const FFmpegfs_Format & fmt : ffmpeg_format)
     {
-        if (ffmpeg_format[n].filetype() != FILETYPE_UNKNOWN && !ffmpeg_format[n].is_sample_fmt_supported())
+        if (fmt.filetype() != FILETYPE_UNKNOWN && !fmt.is_sample_fmt_supported())
         {
-            std::fprintf(stderr, "INVALID PARAMETER: Sample format %s not supported for %s\n\n", get_sampleformat_text(params.m_sample_fmt).c_str(), ffmpeg_format[n].desttype().c_str());
-            std::fprintf(stderr, "Supported formats: %s\n\n", ffmpeg_format[n].sample_fmt_list().c_str());
+            std::fprintf(stderr, "INVALID PARAMETER: Sample format %s not supported for %s\n\n", get_sampleformat_text(params.m_sample_fmt).c_str(), fmt.desttype().c_str());
+            std::fprintf(stderr, "Supported formats: %s\n\n", fmt.sample_fmt_list().c_str());
             return 1;
         }
     }
 
     // Check if audio or video codec is supported
-    for (size_t n = 0; n < 2; n++)
+    for (const FFmpegfs_Format & fmt : ffmpeg_format)
     {
-        if (ffmpeg_format[n].filetype() != FILETYPE_UNKNOWN)
+        if (fmt.filetype() != FILETYPE_UNKNOWN)
         {
-            if (params.m_audio_codec != AV_CODEC_ID_NONE && !ffmpeg_format[n].is_audio_codec_supported(params.m_audio_codec))
+            if (params.m_audio_codec != AV_CODEC_ID_NONE && !fmt.is_audio_codec_supported(params.m_audio_codec))
             {
-                std::fprintf(stderr, "INVALID PARAMETER: Sample format %s not supported for %s\n\n", get_audio_codec_text(params.m_audio_codec).c_str(), ffmpeg_format[n].desttype().c_str());
-                std::fprintf(stderr, "Supported formats: %s\n\n", ffmpeg_format[n].audio_codec_list().c_str());
+                std::fprintf(stderr, "INVALID PARAMETER: Sample format %s not supported for %s\n\n", get_audio_codec_text(params.m_audio_codec).c_str(), fmt.desttype().c_str());
+                std::fprintf(stderr, "Supported formats: %s\n\n", fmt.audio_codec_list().c_str());
                 return 1;
             }
 
-            if (params.m_video_codec != AV_CODEC_ID_NONE && !ffmpeg_format[n].is_video_codec_supported(params.m_video_codec))
+            if (params.m_video_codec != AV_CODEC_ID_NONE && !fmt.is_video_codec_supported(params.m_video_codec))
             {
-                std::fprintf(stderr, "INVALID PARAMETER: Sample format %s not supported for %s\n\n", get_video_codec_text(params.m_video_codec).c_str(), ffmpeg_format[n].desttype().c_str());
-                std::fprintf(stderr, "Supported formats: %s\n\n", ffmpeg_format[n].video_codec_list().c_str());
+                std::fprintf(stderr, "INVALID PARAMETER: Sample format %s not supported for %s\n\n", get_video_codec_text(params.m_video_codec).c_str(), fmt.desttype().c_str());
+                std::fprintf(stderr, "Supported formats: %s\n\n", fmt.video_codec_list().c_str());
                 return 1;
             }
         }
