@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2006-2008 David Collett
  * Copyright (C) 2008-2013 K. Henriksson
- * Copyright (C) 2017-2022 FFmpeg support by Norbert Schlia (nschlia@oblivion-software.de)
+ * Copyright (C) 2017-2023 FFmpeg support by Norbert Schlia (nschlia@oblivion-software.de)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,39 +34,49 @@
  * @author Norbert Schlia (nschlia@oblivion-software.de)
  * @copyright Copyright (C) 2006-2008 David Collett @n
  * Copyright (C) 2008-2013 K. Henriksson @n
- * Copyright (C) 2017-2022 FFmpeg support by Norbert Schlia (nschlia@oblivion-software.de)
+ * Copyright (C) 2017-2023 FFmpeg support by Norbert Schlia (nschlia@oblivion-software.de)
  */
 
 /** @mainpage FFmpegfs FUSE Filesystem
  *
  * @section ffmpeg_introduction Introduction to FFmpegfs
  *
- * FFmpegfs: A read-only FUSE filesystem which transcodes various audio and video formats
- * to MP4, WebM, and many more on the fly when opened and read.
+ * FFmpegfs is a read-only FUSE filesystem which transcodes various audio and video formats to MP4, WebM,
+ * and many more on the fly when opened and read using the FFmpeg library, thus supporting a multitude of
+ * input formats and a variety of common output formats.
  *
- * FFmpegfs can be download [here](https://github.com/nschlia/ffmpegfs).
+ * This allows access to a multi-media file collection with software and/or hardware which only understands
+ * one of the supported output formats, or transcodes files through simple drag-and-drop in a file browser.
  *
- * @section ffmpeg_documentation Documentation
+ * FFmpegfs can be downloaded [from Github](https://github.com/nschlia/ffmpegfs).
  *
- * @li [Read me!](README.md)
- * @li [Man Pages](manpages.html)
- * @li [History](HISTORY.md)
+ * @section ffmpeg_documentation FFmpegfs Documentation
+ *
+ * @li [Introduction](README.md)
+ * @li [**Man Pages**](manpages.html)
+ * @li [Features In Detail](FEATURES.md)
+ * @li [Revision History](HISTORY.md)
  * @li [Installation instructions](INSTALL.md)
+ * @li [Fixing Problems](PROBLEMS.md)
  * @li @ref todo
  * @li @ref bug
  * @li @ref ffmpegfs_NEWS
  * @li @ref ffmpegfs_TODO
+ *
+ * @section ffmpeg_licences Licenses
+ *
  * @li @ref ffmpegfs_COPYING
  * @li @ref ffmpegfs_COPYING.DOC
  * @li @ref ffmpegfs_COPYING.CC0
  *
- * @section ffmpegfs_external External links
+ * @section ffmpegfs_external External Links
  *
- * @li [FFmpeg Homepages](https://www.ffmpeg.org/) @n
+ * @li [**FFmpegfs on Github**](https://github.com/nschlia/ffmpegfs)
+ * @li [**FFmpeg Homepages**](https://www.ffmpeg.org/)
  */
 
 /**
- * @page ffmpegfs_NEWS Online NEWS list
+ * @page ffmpegfs_NEWS Online News List
  *
  * \include NEWS
  *
@@ -89,7 +99,14 @@
 
 #define FUSE_USE_VERSION 26             /**< @brief Requested minimum FUSE version */
 
+#ifdef __cplusplus
+extern "C" {
+#endif
 #include <fuse.h>
+#ifdef __cplusplus
+}
+#endif
+
 #include <stdarg.h>
 
 #include "ffmpeg_utils.h"
@@ -137,7 +154,7 @@ typedef enum HWACCELAPI
 typedef std::multimap<AVCodecID, int> HWACCEL_BLOCKED_MAP;      /**< @brief Map command line option to AVCodecID */
 
 // Format
-extern FFmpegfs_Format  ffmpeg_format[2];                       /**< @brief Two FFmpegfs_Format infos, 0: video file, 1: audio file */
+extern FFMPEGFS_FORMAT_ARR ffmpeg_format;                       /**< @brief Two FFmpegfs_Format infos, 0: video file, 1: audio file */
 
 /**
  * @brief Global program parameters
@@ -157,7 +174,7 @@ extern struct FFMPEGFS_PARAMS
      * @brief Check for smart transcode mode
      * @return true if smart transcode is active, false if not
      */
-    bool                smart_transcode(void) const;
+    bool                smart_transcode() const;
 
     /**
      * @brief Get FFmpegfs_Format for a virtual file.
@@ -223,7 +240,8 @@ extern struct FFMPEGFS_PARAMS
     time_t                  m_expiry_time;                  /**< @brief Time (seconds) after which an cache entry is deleted */
     time_t                  m_max_inactive_suspend;         /**< @brief Time (seconds) that must elapse without access until transcoding is suspended */
     time_t                  m_max_inactive_abort;           /**< @brief Time (seconds) that must elapse without access until transcoding is aborted */
-    size_t                  m_prebuffer_size;               /**< @brief Number of bytes that will be decoded before it can be accessed */
+    time_t                  m_prebuffer_time;               /**< @brief Playing time that will be decoded before the output can be accessed */
+    size_t                  m_prebuffer_size;               /**< @brief Number of bytes that will be decoded before the output can be accessed */
     size_t                  m_max_cache_size;               /**< @brief Max. cache size in MB. When exceeded, oldest entries will be pruned */
     size_t                  m_min_diskspace;                /**< @brief Min. diskspace required for cache */
     std::string             m_cachepath;                    /**< @brief Disk cache path, defaults to $XDG_CACHE_HOME */
@@ -236,8 +254,8 @@ extern struct FFMPEGFS_PARAMS
     int                     m_decoding_errors;              /**< @brief Break transcoding on decoding error */
     int                     m_min_dvd_chapter_duration;     /**< @brief Min. DVD chapter duration. Shorter chapters will be ignored. */
     int                     m_oldnamescheme;                /**< @brief Use old output name scheme, can create duplicate filenames */
-    STRINGSET*              m_extensions;                   /**< @brief List of supplementary file extensions. Must be a pointer as the fuse API cannot handle advanced c++ objects. */
-    STRINGSET*              m_hide_extensions;              /**< @brief Set of extensions to block/hide. Must be a pointer as the fuse API cannot handle advanced c++ objects. */
+    MATCHVEC*               m_include_extensions;           /**< @brief Set of extensions to include. If empty, include all. Must be a pointer as the fuse API cannot handle advanced c++ objects. */
+    MATCHVEC*               m_hide_extensions;              /**< @brief Set of extensions to block/hide. Must be a pointer as the fuse API cannot handle advanced c++ objects. */
     // Experimental options
     int                     m_win_smb_fix;                  /**< @brief Experimental Windows fix for access to EOF at file open */
 } params;                                                   /**< @brief Command line parameters */
@@ -260,7 +278,7 @@ extern thread_pool*     tp;
 /**
  * @brief Initialise FUSE operation structure.
  */
-void            init_fuse_ops(void);
+void            init_fuse_ops();
 
 /**
  * @brief Custom FFmpeg log function. Used with av_log_set_callback().
@@ -290,21 +308,21 @@ void            transcoder_cache_path(std::string & path);
  * @brief Initialise transcoder, create cache.
  * @return Returns true on success; false on error. Check errno for details.
  */
-bool            transcoder_init(void);
+bool            transcoder_init();
 /**
  * @brief Free transcoder.
  */
-void            transcoder_free(void);
+void            transcoder_free();
 /**
  * @brief Run cache maintenance.
  * @return Returns true on success; false on error. Check errno for details.
  */
-bool            transcoder_cache_maintenance(void);
+bool            transcoder_cache_maintenance();
 /**
  * @brief Clear transcoder cache.
  * @return Returns true on success; false on error. Check errno for details.
  */
-bool            transcoder_cache_clear(void);
+bool            transcoder_cache_clear();
 /**
  * @brief Add new virtual file to internal list.
  *
@@ -454,7 +472,7 @@ bool            check_hwaccel_dec_blocked(AVCodecID codec_id, int profile);
  * @param[in] off - Offset of the next entry or zero.
  * @return 1 if buffer is full, zero otherwise or if buf or filler is nullptr.
  */
-int             add_fuse_entry(void *buf, fuse_fill_dir_t filler, const char * name, const struct stat *stbuf, off_t off);
+int             add_fuse_entry(void *buf, fuse_fill_dir_t filler, const std::string & name, const struct stat *stbuf, off_t off);
 
 /**
  * @brief Make dot and double dot entries for a virtual directory.
