@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
  * @ingroup ffmpegfs
  *
  * @author Norbert Schlia (nschlia@oblivion-software.de)
- * @copyright Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * @copyright Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  */
 
 #include "fileio.h"
@@ -43,8 +43,6 @@
 #include "blurayio.h"
 #endif // USE_LIBBLURAY
 
-//#include <assert.h>
-
 uint32_t VIRTUALFILE::get_segment_count() const
 {
     if (m_duration && params.m_segment_duration)
@@ -63,11 +61,6 @@ FileIO::FileIO()
 
 }
 
-FileIO::~FileIO()
-{
-
-}
-
 FileIO * FileIO::alloc(VIRTUALTYPE type)
 {
     switch (type)
