@@ -1,5 +1,5 @@
-﻿/*
- * Copyright (C) 2017-2022 by Norbert Schlia (nschlia@oblivion-software.de)
+/*
+ * Copyright (C) 2017-2023 by Norbert Schlia (nschlia@oblivion-software.de)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@
  * @ingroup ffmpegfs
  *
  * @author Norbert Schlia (nschlia@oblivion-software.de)
- * @copyright Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * @copyright Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  */
 
 #ifndef FILEIO_H
@@ -142,7 +142,7 @@ typedef struct VIRTUALFILE
     VIRTUALTYPE             m_type;                                 /**< @brief Type of this virtual file */
     int                     m_flags;                                /**< @brief One of the VIRTUALFLAG_* flags */
 
-    int                     m_format_idx;                           /**< @brief Index into params.format[] array */
+    size_t                  m_format_idx;                           /**< @brief Index into params.format[] array */
     std::string             m_destfile;                             /**< @brief Name and path of destination file */
     std::string             m_virtfile;                             /**< @brief Name and path of virtual file */
     std::string             m_origfile;                             /**< @brief Sanitised name and path of original file */
@@ -155,7 +155,7 @@ typedef struct VIRTUALFILE
 
     bool                    m_has_audio;                            /**< @brief True if file has an audio track */
     bool                    m_has_video;                            /**< @brief True if file has a video track */
-    bool                    m_has_subtitle;                            /**< @brief True if file has a subtitle track */
+    bool                    m_has_subtitle;                         /**< @brief True if file has a subtitle track */
 
     std::vector<char>       m_file_contents;                        /**< @brief Buffer for virtual files */
 
@@ -262,7 +262,7 @@ public:
     /**
      * @brief Free #FileIO object
      */
-    virtual ~FileIO();
+    virtual ~FileIO() = default;
 
     /** @brief Allocate the correct object for type().
      *
@@ -286,19 +286,19 @@ public:
     virtual size_t  	bufsize() const = 0;
     /** @brief Open a virtual file.
      * @param[in] virtualfile - LPCVIRTUALFILE of file to open.
-     * @return Upon successful completion, #open() returns 0. @n
+     * @return Upon successful completion, #openio() returns 0. @n
      * On error, a nonzero value is returned and errno is set to indicate the error.
      */
-    virtual int         open(LPVIRTUALFILE virtualfile) = 0;
+    virtual int         openio(LPVIRTUALFILE virtualfile) = 0;
     /** @brief Read data from a file.
      * @param[out] data - A buffer to store read bytes in. It must be large enough to hold up to size bytes.
      * @param[in] size - The number of bytes to read.
-     * @return Upon successful completion, #read() returns the number of bytes read. @n
+     * @return Upon successful completion, #readio() returns the number of bytes read. @n
      * This may be less than size. @n
      * On error, the value 0 is returned and errno is set to indicate the error. @n
      * If at the end of the file, 0 may be returned but errno is not set. error() will return 0 if at EOF.
      */
-    virtual size_t      read(void *data, size_t size) = 0;
+    virtual size_t      readio(void *data, size_t size) = 0;
     /**
      * @brief Get last error.
      * @return errno value of last error.
@@ -342,7 +342,7 @@ public:
     /**
      * @brief Close virtual file.
      */
-    virtual void        close() = 0;
+    virtual void        closeio() = 0;
     /**
      * @brief Get virtual file object
      * @return Current virtual file object or nullptr if unset.
