@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2006-2008 David Collett
  * Copyright (C) 2008-2012 K. Henriksson
- * Copyright (C) 2017-2022 FFmpeg support by Norbert Schlia (nschlia@oblivion-software.de)
+ * Copyright (C) 2017-2023 FFmpeg support by Norbert Schlia (nschlia@oblivion-software.de)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,11 +30,10 @@
  * @author Norbert Schlia (nschlia@oblivion-software.de)
  * @copyright Copyright (C) 2006-2008 David Collett @n
  * Copyright (C) 2008-2013 K. Henriksson @n
- * Copyright (C) 2017-2022 FFmpeg support by Norbert Schlia (nschlia@oblivion-software.de)
+ * Copyright (C) 2017-2023 FFmpeg support by Norbert Schlia (nschlia@oblivion-software.de)
  */
 
 #include "transcode.h"
-//#include "ffmpeg_utils.h"
 #include "cache_maintenance.h"
 #include "logging.h"
 #ifdef USE_LIBVCD
@@ -52,11 +51,8 @@
 #include "cache_entry.h"
 
 #include <dirent.h>
-#include <unistd.h>
-#include <regex>
 #include <list>
-#include <assert.h>
-#include <signal.h>
+#include <csignal>
 #include <cstring>
 
 typedef std::map<const std::string, VIRTUALFILE> FILENAME_MAP;      /**< @brief Map virtual file names to virtual file objects. */
@@ -76,7 +72,7 @@ static int                          make_hls_fileset(void * buf, fuse_fill_dir_t
 static int                          kick_next(LPVIRTUALFILE virtualfile);
 static void                         sighandler(int signum);
 static std::string                  get_number(const char *path, uint32_t *value);
-static int                          guess_format_idx(const std::string & filepath);
+static size_t                       guess_format_idx(const std::string & filepath);
 static int                          parse_file(LPVIRTUALFILE newvirtualfile);
 static const FFmpegfs_Format * 		get_format(LPVIRTUALFILE newvirtualfile);
 static int                          selector(const struct dirent * de);
@@ -248,7 +244,7 @@ static bool is_passthrough(const std::string & ext)
     return (passthrough_set.find(ext) != passthrough_set.cend());
 }
 
-void init_fuse_ops(void)
+void init_fuse_ops()
 {
     memset(&ffmpegfs_ops, 0, sizeof(fuse_operations));
     ffmpegfs_ops.getattr  = ffmpegfs_getattr;
@@ -379,9 +375,9 @@ static int ffmpegfs_readdir(const char *path, void *buf, fuse_fill_dir_t filler,
                 }
 
                 // Process files
-                for (std::map<const std::string, struct stat>::iterator it = files.begin(); it != files.end(); ++it)
+                for (auto& [key, value] : files)
                 {
-                    std::string origname(it->first);
+                    std::string origname(key);
 
                     if (is_blocked(origname))
                     {
@@ -389,8 +385,8 @@ static int ffmpegfs_readdir(const char *path, void *buf, fuse_fill_dir_t filler,
                     }
 
                     std::string origfile;
-                    std::string filename(it->first);
-                    struct stat & stbuf = it->second;
+                    std::string filename(key);
+                    struct stat & stbuf = value;
                     int flags = 0;
 
                     origfile = origpath + origname;
@@ -463,7 +459,7 @@ static int ffmpegfs_readdir(const char *path, void *buf, fuse_fill_dir_t filler,
 
                     if (!(flags & VIRTUALFLAG_HIDDEN))
                     {
-                        if (add_fuse_entry(buf, filler, filename.c_str(), &stbuf, 0))
+                        if (add_fuse_entry(buf, filler, filename, &stbuf, 0))
                         {
                             break;
                         }
@@ -673,7 +669,7 @@ static int ffmpegfs_getattr(const char *path, struct stat *stbuf)
                     remove_filename(&pathonly);
 
 #ifdef USE_LIBVCD
-                    if (res <= 0)
+                    //if (res <= 0) Not necessary here, will always be true
                     {
                         // Returns -errno or number or titles on VCD
                         res = check_vcd(pathonly);
@@ -819,8 +815,6 @@ static int ffmpegfs_getattr(const char *path, struct stat *stbuf)
                     return -EBADF;
                 }
 
-                assert(virtualfile->m_origfile == origpath);
-
                 if (!transcoder_cached_filesize(virtualfile, stbuf))
                 {
                     Cache_Entry* cache_entry = transcoder_new(virtualfile, false);
@@ -849,7 +843,6 @@ static int ffmpegfs_getattr(const char *path, struct stat *stbuf)
     case VIRTUALTYPE_PASSTHROUGH:
     case VIRTUALTYPE_BUFFER:
     {
-        assert(false);
         break;
     }
     }
@@ -895,7 +888,6 @@ static int ffmpegfs_fgetattr(const char *path, struct stat * stbuf, struct fuse_
     }
 
     // This is a virtual file
-    assert(virtualfile != nullptr);
 
     bool no_check = false;
 
@@ -963,7 +955,6 @@ static int ffmpegfs_fgetattr(const char *path, struct stat * stbuf, struct fuse_
     case VIRTUALTYPE_PASSTHROUGH:
     case VIRTUALTYPE_BUFFER:
     {
-        assert(false);
         break;
     }
     }
@@ -1080,7 +1071,6 @@ static int ffmpegfs_open(const char *path, struct fuse_file_info *fi)
     case VIRTUALTYPE_PASSTHROUGH:
     case VIRTUALTYPE_BUFFER:
     {
-        assert(false);
         break;
     }
     }
@@ -1141,7 +1131,12 @@ static int ffmpegfs_read(const char *path, char *buf, size_t size, off_t offset,
     // This is a virtual file
     bool success = true;
 
-    assert(virtualfile != nullptr);
+    if (virtualfile == nullptr)
+    {
+        errno = EINVAL;
+        Logging::error(origpath.c_str(), "read: INTERNAL ERROR: ffmpegfs_read()! virtualfile == NULL");
+        return -errno;
+    }
 
     switch (virtualfile->m_type)
     {
@@ -1239,7 +1234,6 @@ static int ffmpegfs_read(const char *path, char *buf, size_t size, off_t offset,
     case VIRTUALTYPE_PASSTHROUGH:
     case VIRTUALTYPE_BUFFER:
     {
-        assert(false);
         break;
     }
     }
@@ -1269,9 +1263,11 @@ static int ffmpegfs_statfs(const char *path, struct statvfs *stbuf)
     append_basepath(&origpath, path);
 
     // passthrough for regular files
-    if (statvfs(origpath.c_str(), stbuf) == 0)
+    if (!origpath.empty() && statvfs(origpath.c_str(), stbuf) == 0)
     {
-        return -errno;
+        errno = 0;  // Just to make sure - reset any error
+
+        return 0;
     }
     else
     {
@@ -1390,8 +1386,7 @@ static void ffmpegfs_destroy(__attribute__((unused)) void * p)
     if (tp != nullptr)
     {
         tp->tear_down();
-        delete tp;
-        tp = nullptr;
+        save_delete(&tp);
     }
 
     script_file.clear();
@@ -1471,7 +1466,7 @@ static LPVIRTUALFILE make_file(void *buf, fuse_fill_dir_t filler, VIRTUALTYPE ty
 
     init_stat(&stbuf, fsize, ftime, false);
 
-    if (add_fuse_entry(buf, filler, filename.c_str(), &stbuf, 0))
+    if (add_fuse_entry(buf, filler, filename, &stbuf, 0))
     {
         return nullptr;
     }
@@ -1545,42 +1540,9 @@ static bool virtual_name(std::string * virtualpath, const std::string & origpath
         return false;
     }
 
-    if (allow_list_ext(ext))
+    if (!is_selected(ext))
     {
-        const FFmpegfs_Format *ffmpegfs_format = nullptr;
-
-        if (!params.smart_transcode())
-        {
-            // Not smart encoding: use first format (video file)
-            ffmpegfs_format = &ffmpeg_format[0];
-        }
-        else if (ffmpeg_format[1].audio_codec() != AV_CODEC_ID_NONE)
-        {
-            // We have an audio track
-            ffmpegfs_format = &ffmpeg_format[1];
-        }
-
-        if (ffmpegfs_format != nullptr)
-        {
-            // Could determine format
-            if (params.m_oldnamescheme)
-            {
-                // Old filename scheme, creates duplicates
-                replace_ext(virtualpath, ffmpegfs_format->fileext());
-            }
-            else
-            {
-                // New name scheme
-                append_ext(virtualpath, ffmpegfs_format->fileext());
-            }
-
-            if (current_format != nullptr)
-            {
-                *current_format = ffmpegfs_format;
-            }
-
-            return true;
-        }
+        return false;
     }
 
     VIRTUALFILE newvirtualfile;
@@ -1858,7 +1820,7 @@ int load_path(const std::string & path, const struct stat *statbuf, void *buf, f
                 }
             }
 
-            if (add_fuse_entry(buf, filler, destfile.c_str(), &stbuf, 0))
+            if (add_fuse_entry(buf, filler, destfile, &stbuf, 0))
             {
                 // break;
             }
@@ -2058,7 +2020,7 @@ static int make_hls_fileset(void * buf, fuse_fill_dir_t filler, const std::strin
                 "#EXT-X-STREAM-INF:PROGRAM-ID=1\n"
                 "index_0_av.m3u8\n";
 
-        index_0_av_contents = strsprintf("#EXTM3U\n"
+        strsprintf(&index_0_av_contents, "#EXTM3U\n"
                 "#EXT-X-TARGETDURATION:%i\n"
                 "#EXT-X-ALLOW-CACHE:YES\n"
                 "#EXT-X-PLAYLIST-TYPE:VOD\n"
@@ -2067,7 +2029,6 @@ static int make_hls_fileset(void * buf, fuse_fill_dir_t filler, const std::strin
 
         int64_t remaining_duration  = virtualfile->m_duration % params.m_segment_duration;
         size_t  segment_size        = virtualfile->m_predicted_size / virtualfile->get_segment_count();
-        size_t  remaining_size      = virtualfile->m_predicted_size % virtualfile->get_segment_count();
 
         for (uint32_t file_no = 1; file_no <= virtualfile->get_segment_count(); file_no++)
         {
@@ -2078,7 +2039,13 @@ static int make_hls_fileset(void * buf, fuse_fill_dir_t filler, const std::strin
             std::string cachefile;
             std::string _origpath(origpath);
             remove_sep(&_origpath);
-            Buffer::make_cachefile_name(cachefile, _origpath + "." + segment_name, params.current_format(virtualfile)->fileext(), false);
+
+            std::string filename(_origpath);
+
+            filename.append(".");
+            filename.append(segment_name);
+
+            Buffer::make_cachefile_name(cachefile, filename, params.current_format(virtualfile)->fileext(), false);
 
             if (!lstat(cachefile.c_str(), &stbuf))
             {
@@ -2086,23 +2053,16 @@ static int make_hls_fileset(void * buf, fuse_fill_dir_t filler, const std::strin
             }
             else
             {
-                if (file_no < virtualfile->get_segment_count())
-                {
-                    make_file(buf, filler, virtualfile->m_type, origpath, segment_name, segment_size, virtualfile->m_st.st_ctime, VIRTUALFLAG_HLS);
-                }
-                else
-                {
-                    make_file(buf, filler, virtualfile->m_type, origpath, segment_name, remaining_size, virtualfile->m_st.st_ctime, VIRTUALFLAG_HLS);
-                }
+                make_file(buf, filler, virtualfile->m_type, origpath, segment_name, segment_size, virtualfile->m_st.st_ctime, VIRTUALFLAG_HLS);
             }
 
             if (file_no < virtualfile->get_segment_count())
             {
-                buffer = strsprintf("#EXTINF:%.3f,\n", static_cast<double>(params.m_segment_duration) / AV_TIME_BASE);
+                strsprintf(&buffer, "#EXTINF:%.3f,\n", static_cast<double>(params.m_segment_duration) / AV_TIME_BASE);
             }
             else
             {
-                buffer = strsprintf("#EXTINF:%.3f,\n", static_cast<double>(remaining_duration) / AV_TIME_BASE);
+                strsprintf(&buffer, "#EXTINF:%.3f,\n", static_cast<double>(remaining_duration) / AV_TIME_BASE);
             }
 
             index_0_av_contents += buffer;
@@ -2222,8 +2182,6 @@ static int kick_next(LPVIRTUALFILE virtualfile)
  */
 static void sighandler(int signum)
 {
-    assert(signum == SIGINT);
-
     if (signum == SIGINT)
     {
         Logging::warning(nullptr, "Caught SIGINT, shutting down now...");
@@ -2249,7 +2207,7 @@ static std::string get_number(const char *path, uint32_t *value)
     // Get frame number
     remove_path(&filename);
 
-    *value = static_cast<uint32_t>(atoi(filename.c_str())); // Extract frame or segment number. May be more fancy in the future. Currently just get number from filename part.
+    *value = static_cast<uint32_t>(std::stoi(filename)); // Extract frame or segment number. May be more fancy in the future. Currently just get number from filename part.
 
     return filename;
 }
@@ -2259,7 +2217,7 @@ static std::string get_number(const char *path, uint32_t *value)
  * @param[in] filepath - Name of the file, path my be included, but not required.
  * @return Index 0 or 1
  */
-static int guess_format_idx(const std::string & filepath)
+static size_t guess_format_idx(const std::string & filepath)
 {
     const AVOutputFormat* oformat = ::av_guess_format(nullptr, filepath.c_str(), nullptr);
 
@@ -2434,14 +2392,14 @@ static const FFmpegfs_Format * get_format(LPVIRTUALFILE newvirtualfile)
     return nullptr;
 }
 
-int add_fuse_entry(void *buf, fuse_fill_dir_t filler, const char * name, const struct stat *stbuf, off_t off)
+int add_fuse_entry(void *buf, fuse_fill_dir_t filler, const std::string & name, const struct stat *stbuf, off_t off)
 {
     if (buf == nullptr || filler == nullptr)
     {
         return 0;
     }
 
-    return filler(buf, name, stbuf, off);
+    return filler(buf, name.c_str(), stbuf, off);
 }
 
 int add_dotdot(void *buf, fuse_fill_dir_t filler, const struct stat *stbuf, off_t off)
