@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * Copyright (C) 2019-2023 Norbert Schlia (nschlia@oblivion-software.de)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
  * @ingroup ffmpegfs
  *
  * @author Norbert Schlia (nschlia@oblivion-software.de)
- * @copyright Copyright (C) 2019-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * @copyright Copyright (C) 2019-2023 Norbert Schlia (nschlia@oblivion-software.de)
  */
 
 #include "thread_pool.h"
@@ -133,7 +133,7 @@ void thread_pool::init(unsigned int num_threads /*= 0*/)
 
     for(unsigned int i = 0; i < m_num_threads; i++)
     {
-        m_thread_pool.push_back(std::thread(&thread_pool::loop_function_starter, std::ref(*this)));
+        m_thread_pool.emplace_back(std::thread(&thread_pool::loop_function_starter, std::ref(*this)));
     }
 }
 
