@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * Copyright (C) 2019-2023 Norbert Schlia (nschlia@oblivion-software.de)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,12 +26,18 @@
  * @ingroup ffmpegfs
  *
  * @author Norbert Schlia (nschlia@oblivion-software.de)
- * @copyright Copyright (C) 2019-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * @copyright Copyright (C) 2019-2023 Norbert Schlia (nschlia@oblivion-software.de)
  */
 
 #ifndef THREAD_POOL_H
 #define THREAD_POOL_H
 
+#pragma once
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <iostream>
 #include <thread>
 #include <vector>
