@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2006-2008 David Collett
  * Copyright (C) 2008-2013 K. Henriksson
- * Copyright (C) 2017-2022 FFmpeg support by Norbert Schlia (nschlia@oblivion-software.de)
+ * Copyright (C) 2017-2023 FFmpeg support by Norbert Schlia (nschlia@oblivion-software.de)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
  * @author Norbert Schlia (nschlia@oblivion-software.de)
  * @copyright Copyright (C) 2006-2008 David Collett @n
  * Copyright (C) 2008-2013 K. Henriksson @n
- * Copyright (C) 2017-2022 FFmpeg support by Norbert Schlia (nschlia@oblivion-software.de)
+ * Copyright (C) 2017-2023 FFmpeg support by Norbert Schlia (nschlia@oblivion-software.de)
  */
 
 #include "transcode.h"
@@ -47,8 +47,8 @@
 
 
 #define MS              *1000000L   /**< @brief 1 millisecond = 1,000,000 Nanoseconds */
-#define GRANULARITY     250         /**< @brief Image frame conversion: ms between checks if a picture frame is avaiable */
-#define FRAME_TIMEOUT   10          /**< @brief Image frame conversion: timoute seconds to wait if a picture frame is avaiable */
+#define GRANULARITY     250         /**< @brief Image frame conversion: ms between checks if a picture frame is available */
+#define FRAME_TIMEOUT   10          /**< @brief Image frame conversion: timoute seconds to wait if a picture frame is available */
 
 /**
   * @brief THREAD_DATA struct to pass data from parent to child thread
@@ -183,7 +183,7 @@ static int transcode_finish(Cache_Entry* cache_entry, FFmpeg_Transcoder &transco
                        format_size_ex(cache_entry->m_cache_info.m_predicted_filesize).c_str(),
                        format_size_ex(cache_entry->m_cache_info.m_encoded_filesize).c_str(),
                        format_result_size_ex(cache_entry->m_cache_info.m_encoded_filesize, cache_entry->m_cache_info.m_predicted_filesize).c_str(),
-                       static_cast<double>((cache_entry->m_cache_info.m_encoded_filesize * 1000 / (cache_entry->m_cache_info.m_predicted_filesize + 1)) + 5) / 10);
+                       ((static_cast<double>(cache_entry->m_cache_info.m_encoded_filesize) * 1000 / (static_cast<double>(cache_entry->m_cache_info.m_predicted_filesize) + 1)) + 5) / 10);
     }
 
     cache_entry->flush();
@@ -225,7 +225,7 @@ void transcoder_cache_path(std::string & path)
     append_sep(&path);
 }
 
-bool transcoder_init(void)
+bool transcoder_init()
 {
     if (cache == nullptr)
     {
@@ -247,7 +247,7 @@ bool transcoder_init(void)
     return true;
 }
 
-void transcoder_free(void)
+void transcoder_free()
 {
     Cache *p1 = cache;
     cache = nullptr;
@@ -261,7 +261,7 @@ void transcoder_free(void)
 
 bool transcoder_cached_filesize(LPVIRTUALFILE virtualfile, struct stat *stbuf)
 {
-    Cache_Entry* cache_entry = cache->open(virtualfile);
+    Cache_Entry* cache_entry = cache->openio(virtualfile);
     if (cache_entry == nullptr)
     {
         return false;
@@ -286,9 +286,9 @@ bool transcoder_cached_filesize(LPVIRTUALFILE virtualfile, struct stat *stbuf)
     }
 }
 
-bool transcoder_set_filesize(LPVIRTUALFILE virtualfile, int64_t duration, BITRATE audio_bit_rate, int channels, int sample_rate, AVSampleFormat sample_format, BITRATE video_bit_rate, int width, int height, int interleaved, const AVRational &framerate)
+bool transcoder_set_filesize(LPVIRTUALFILE virtualfile, int64_t duration, BITRATE audio_bit_rate, int channels, int sample_rate, AVSampleFormat sample_format, BITRATE video_bit_rate, int width, int height, bool interleaved, const AVRational &framerate)
 {
-    Cache_Entry* cache_entry = cache->open(virtualfile);
+    Cache_Entry* cache_entry = cache->openio(virtualfile);
     if (cache_entry == nullptr)
     {
         Logging::error(nullptr, "Out of memory getting file size.");
@@ -306,12 +306,12 @@ bool transcoder_set_filesize(LPVIRTUALFILE virtualfile, int64_t duration, BITRAT
 
     if (!FFmpeg_Transcoder::audio_size(&filesize, current_format->audio_codec(), audio_bit_rate, duration, channels, sample_rate, sample_format))
     {
-        Logging::warning(cache_entry->virtname(), "Unsupported audio codec '%1' for format %2.", get_codec_name(current_format->audio_codec(), 0), current_format->desttype().c_str());
+        Logging::warning(cache_entry->virtname(), "Unsupported audio codec '%1' for format %2.", get_codec_name(current_format->audio_codec(), false), current_format->desttype().c_str());
     }
 
     if (!FFmpeg_Transcoder::video_size(&filesize, current_format->video_codec(), video_bit_rate, duration, width, height, interleaved, framerate))
     {
-        Logging::warning(cache_entry->virtname(), "Unsupported video codec '%1' for format %2.", get_codec_name(current_format->video_codec(), 0), current_format->desttype().c_str());
+        Logging::warning(cache_entry->virtname(), "Unsupported video codec '%1' for format %2.", get_codec_name(current_format->video_codec(), false), current_format->desttype().c_str());
     }
 
     if (!FFmpeg_Transcoder::total_overhead(&filesize, current_format->filetype()))
@@ -343,7 +343,7 @@ bool transcoder_predict_filesize(LPVIRTUALFILE virtualfile, Cache_Entry* cache_e
 
         Logging::trace(transcoder.filename(), "Predicted transcoded size of %1.", format_size_ex(transcoder.predicted_filesize()).c_str());
 
-        transcoder.close();
+        transcoder.closeio();
 
         success = true;
     }
@@ -354,7 +354,7 @@ bool transcoder_predict_filesize(LPVIRTUALFILE virtualfile, Cache_Entry* cache_e
 Cache_Entry* transcoder_new(LPVIRTUALFILE virtualfile, bool begin_transcode)
 {
     // Allocate transcoder structure
-    Cache_Entry* cache_entry = cache->open(virtualfile);
+    Cache_Entry* cache_entry = cache->openio(virtualfile);
     if (cache_entry == nullptr)
     {
         return nullptr;
@@ -366,7 +366,7 @@ Cache_Entry* transcoder_new(LPVIRTUALFILE virtualfile, bool begin_transcode)
     {
         cache_entry->lock();
 
-        if (!cache_entry->open(begin_transcode))
+        if (!cache_entry->openio(begin_transcode))
         {
             throw static_cast<int>(errno);
         }
@@ -459,7 +459,7 @@ Cache_Entry* transcoder_new(LPVIRTUALFILE virtualfile, bool begin_transcode)
     {
         cache_entry->m_is_decoding = false;
         cache_entry->unlock();
-        cache->close(&cache_entry, CACHE_CLOSE_DELETE);
+        cache->closeio(&cache_entry, CACHE_CLOSE_DELETE);
         cache_entry = nullptr;  // Make sure to return NULL here even if the cache could not be deleted now (still in use)
         errno = orgerrno;         // Restore last errno
     }
@@ -715,7 +715,7 @@ bool transcoder_read_frame(Cache_Entry* cache_entry, char* buff, size_t offset,
 
 void transcoder_delete(Cache_Entry* cache_entry)
 {
-    cache->close(&cache_entry);
+    cache->closeio(&cache_entry);
 }
 
 size_t transcoder_get_size(Cache_Entry* cache_entry)
@@ -733,12 +733,12 @@ size_t transcoder_buffer_tell(Cache_Entry* cache_entry, uint32_t segment_no)
     return cache_entry->m_buffer->tell(segment_no);
 }
 
-void transcoder_exit(void)
+void transcoder_exit()
 {
     thread_exit = true;
 }
 
-bool transcoder_cache_maintenance(void)
+bool transcoder_cache_maintenance()
 {
     if (cache != nullptr)
     {
@@ -750,7 +750,7 @@ bool transcoder_cache_maintenance(void)
     }
 }
 
-bool transcoder_cache_clear(void)
+bool transcoder_cache_clear()
 {
     if (cache != nullptr)
     {
@@ -791,7 +791,7 @@ static int transcoder_thread(void *arg)
 
         Logging::info(cache_entry->filename(), "Transcoding to %1.", params.current_format(cache_entry->virtualfile())->desttype().c_str());
 
-        if (!cache_entry->open())
+        if (!cache_entry->openio())
         {
             throw (static_cast<int>(errno));
         }
@@ -843,7 +843,7 @@ static int transcoder_thread(void *arg)
         thread_data->m_initialised = true;
 
         unlocked = false;
-        if (!params.m_prebuffer_size || transcoder.is_frameset())
+        if ((!params.m_prebuffer_size && !params.m_prebuffer_time) || transcoder.is_frameset())
         {
             // Unlock frame set from beginning
             unlocked = true;
@@ -852,7 +852,14 @@ static int transcoder_thread(void *arg)
         }
         else
         {
-            Logging::debug(cache_entry->virtname(), "Pre-buffering up to %1 bytes.", params.m_prebuffer_size);
+            if (params.m_prebuffer_time)
+            {
+                Logging::debug(cache_entry->virtname(), "Pre-buffering up to %1.", format_time(params.m_prebuffer_time).c_str());
+            }
+            if (params.m_prebuffer_size)
+            {
+                Logging::debug(cache_entry->virtname(), "Pre-buffering up to %1.", format_size(params.m_prebuffer_size).c_str());
+            }
         }
 
         while (!cache_entry->is_finished() && !(timeout = cache_entry->decode_timeout()) && !thread_exit)
@@ -907,7 +914,7 @@ static int transcoder_thread(void *arg)
                 throw (static_cast<int>(errno));
             }
 
-            if (!unlocked && cache_entry->m_buffer->buffer_watermark() > params.m_prebuffer_size)
+            if (!unlocked && cache_entry->m_buffer->buffer_watermark() > params.m_prebuffer_size && transcoder.pts() > static_cast<int64_t>(params.m_prebuffer_time) * AV_TIME_BASE)
             {
                 unlocked = true;
                 Logging::debug(cache_entry->virtname(), "Pre-buffer limit reached.");
@@ -917,7 +924,7 @@ static int transcoder_thread(void *arg)
 
             if (cache_entry->ref_count() <= 1 && cache_entry->suspend_timeout())
             {
-                if (!unlocked && params.m_prebuffer_size)
+                if (!unlocked && (params.m_prebuffer_size || params.m_prebuffer_time))
                 {
                     unlocked = true;
                     thread_data->m_lock_guard = true;
@@ -941,7 +948,7 @@ static int transcoder_thread(void *arg)
             }
         }
 
-        if (!unlocked && params.m_prebuffer_size)
+        if (!unlocked && (params.m_prebuffer_size || params.m_prebuffer_time))
         {
             Logging::debug(cache_entry->virtname(), "File transcode complete, releasing buffer early: Size %1.", cache_entry->m_buffer->buffer_watermark());
             thread_data->m_lock_guard = true;
@@ -969,7 +976,7 @@ static int transcoder_thread(void *arg)
         thread_data->m_cond.notify_all();           // unlock main thread
     }
 
-    transcoder.close();
+    transcoder.closeio();
 
     if (timeout || thread_exit || transcoder.have_seeked())
     {
@@ -1025,7 +1032,7 @@ static int transcoder_thread(void *arg)
         }
     }
 
-    cache->close(&cache_entry, timeout ? CACHE_CLOSE_DELETE : CACHE_CLOSE_NOOPT);
+    cache->closeio(&cache_entry, timeout ? CACHE_CLOSE_DELETE : CACHE_CLOSE_NOOPT);
 
     delete thread_data;
 
@@ -1151,7 +1158,7 @@ void ffmpeg_log(void *ptr, int level, const char *fmt, va_list vl)
         }
         default:
         {
-            category = strsprintf("CAT %3i ", static_cast<int>(avc->category));
+            strsprintf(&category, "CAT %3i ", static_cast<int>(avc->category));
             break;
         }
         }
