@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2006-2008 David Collett @n
  * Copyright (C) 2008-2013 K. Henriksson @n
- * Copyright (C) 2017-2022 FFmpeg support by Norbert Schlia (nschlia@oblivion-software.de)
+ * Copyright (C) 2017-2023 FFmpeg support by Norbert Schlia (nschlia@oblivion-software.de)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
  * @author Norbert Schlia (nschlia@oblivion-software.de)
  * @copyright Copyright (C) 2006-2008 David Collett @n
  * Copyright (C) 2008-2013 K. Henriksson @n
- * Copyright (C) 2017-2022 FFmpeg support by Norbert Schlia (nschlia@oblivion-software.de)
+ * Copyright (C) 2017-2023 FFmpeg support by Norbert Schlia (nschlia@oblivion-software.de)
  */
 
 #ifndef TRANSCODE_H
@@ -59,11 +59,11 @@ bool            transcoder_cached_filesize(LPVIRTUALFILE virtualfile, struct sta
  * @param[in] video_bit_rate - average bitrate of video data (in bits per second).
  * @param[in] width - video width in pixels.
  * @param[in] height - video height in pixels.
- * @param[in] interleaved - 1 if video is interleaved, 0 if not.
+ * @param[in] interleaved - true if video is interleaved, false if not.
  * @param[in] framerate - frame rate per second (e.g. 24, 25, 30...).
  * @return On error, returns false (size could not be set) or true on success.
  */
-bool            transcoder_set_filesize(LPVIRTUALFILE virtualfile, int64_t duration, BITRATE audio_bit_rate, int channels, int sample_rate, AVSampleFormat sample_format, BITRATE video_bit_rate, int width, int height, int interleaved, const AVRational & framerate);
+bool            transcoder_set_filesize(LPVIRTUALFILE virtualfile, int64_t duration, BITRATE audio_bit_rate, int channels, int sample_rate, AVSampleFormat sample_format, BITRATE video_bit_rate, int width, int height, bool interleaved, const AVRational & framerate);
 /**
  * @brief Predict file size
  * @param[in] virtualfile - virtual file object to open
@@ -154,6 +154,6 @@ size_t          transcoder_buffer_tell(Cache_Entry* cache_entry, uint32_t segmen
  *
  * Send signal to exit transcoding (ending all transcoder threads).
  */
-void            transcoder_exit(void);
+void            transcoder_exit();
 
 #endif
