@@ -21,15 +21,16 @@
  * @ingroup ffmpegfs
  *
  * @author Norbert Schlia (nschlia@oblivion-software.de)
- * @copyright Copyright (C) 2013-2022 Norbert Schlia (nschlia@oblivion-software.de) @n
- * From BullysPLayer Copyright (C) 1984-2022 by Oblivion Software/Norbert Schlia
+ * @copyright Copyright (C) 2013-2023 Norbert Schlia (nschlia@oblivion-software.de) @n
+ * From BullysPLayer Copyright (C) 1984-2023 by Oblivion Software/Norbert Schlia
  */
 
-#pragma once
-
 #ifndef VCDCHAPTER_H
 #define VCDCHAPTER_H
 
+#pragma once
+
+#include <cstdint>
 #include <string>
 
 /**
@@ -86,7 +87,7 @@ public:
     /**
      * @brief Destroy VcdChapter object
      */
-    virtual ~VcdChapter();
+    virtual ~VcdChapter() = default;
 
     /**
      * @brief Check if this is a Super Video CD.
@@ -204,7 +205,7 @@ protected:
      * @param[in] track_no - Track number 1...
      * @return
      */
-    int         read(FILE *fpi, int track_no);
+    int         readio(FILE *fpi, int track_no);
 
 protected:
     bool        m_is_svcd;                              /**< @brief true for SVCD, false for VCD */
