@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,23 +23,16 @@
  * @ingroup ffmpegfs
  *
  * @author Norbert Schlia (nschlia@oblivion-software.de)
- * @copyright Copyright (C) 2013-2022 Norbert Schlia (nschlia@oblivion-software.de) @n
- * From BullysPLayer Copyright (C) 1984-2022 by Oblivion Software/Norbert Schlia
+ * @copyright Copyright (C) 2013-2023 Norbert Schlia (nschlia@oblivion-software.de) @n
+ * From BullysPLayer Copyright (C) 1984-2023 by Oblivion Software/Norbert Schlia
  */
 
-#include <string>
-
-#ifdef _WIN32
-#include <winsock2.h>
-#else
-#include <arpa/inet.h>
-#endif
-
+#include "ffmpegfs.h"
 #include "vcdentries.h"
 #include "vcdutils.h"
-#include "ffmpegfs.h"
 
-#include <string.h>
+#include <arpa/inet.h>
+#include <cstring>
 #include <sys/stat.h>
 
 #define VCD_SECTOR_SIZE 2352                /**< @brief Video CD sector size */
@@ -49,7 +42,7 @@
 /**
   * Sync bytes for a Video CD sector.
   */
-const char SYNC[12]              = { '\x00', '\xFF', '\xFF', '\xFF', '\xFF', '\xFF', '\xFF', '\xFF', '\xFF', '\xFF', '\xFF', '\x00' };
+const std::array<char, 12> SYNC = { '\x00', '\xFF', '\xFF', '\xFF', '\xFF', '\xFF', '\xFF', '\xFF', '\xFF', '\xFF', '\xFF', '\x00' };
 /**
   * Sync bytes for a Video CD picture start.
   */
@@ -64,10 +57,6 @@ VcdEntries::VcdEntries()
     clear();
 }
 
-VcdEntries::~VcdEntries()
-{
-}
-
 void VcdEntries::clear()
 {
     m_file_date     = -1;
@@ -175,6 +164,8 @@ int VcdEntries::scan_chapters()
     std::string fullname;
     struct stat stbuf;
 
+    memset(&stbuf, 0, sizeof(stbuf));
+
     if (!m_chapters.size())
     {
         return EIO;   // Fail safe only: Should not happen, at least 1 chapter is required.
@@ -221,14 +212,14 @@ int VcdEntries::scan_chapters()
                 }
 
                 // Locate the first sync bytes
-                SEEKRES res = seek_sync(fpi, SYNC, sizeof(SYNC));
+                SEEKRES res = seek_sync(fpi, SYNC);
 
                 if (res != SEEKRES_FOUND)
                 {
                     throw static_cast<int>(EIO);
                 }
 
-                first_sync = ftell(fpi) - static_cast<int64_t>(sizeof(SYNC));
+                first_sync = ftell(fpi) - static_cast<int64_t>(SYNC.size());
             }
 
             int64_t total_chunks    = (stbuf.st_size - first_sync) / VCD_SECTOR_SIZE;
@@ -240,14 +231,14 @@ int VcdEntries::scan_chapters()
             while (first <= last)
             {
                 VcdChapter buffer(m_chapters[chapter_no].get_is_svcd());
-                __off_t file_pos = static_cast<__off_t>(first_sync + middle * VCD_SECTOR_SIZE);
+                long int file_pos = static_cast<long int>(first_sync + middle * VCD_SECTOR_SIZE);
 
                 if (fseek(fpi, file_pos, SEEK_SET))
                 {
                     throw static_cast<int>(ferror(fpi));
                 }
 
-                int orgerrno = buffer.read(fpi, last_track_no);
+                int orgerrno = buffer.readio(fpi, last_track_no);
                 if (orgerrno)
                 {
                     throw static_cast<int>(orgerrno);
@@ -286,7 +277,7 @@ int VcdEntries::scan_chapters()
                 throw static_cast<int>(ferror(fpi));
             }
 
-            int orgerrno = buffer.read(fpi, last_track_no);
+            int orgerrno = buffer.readio(fpi, last_track_no);
             if (orgerrno)
             {
                 throw static_cast<int>(orgerrno);
@@ -321,7 +312,7 @@ int VcdEntries::scan_chapters()
     return 0;
 }
 
-VcdEntries::SEEKRES VcdEntries::seek_sync(FILE *fpi, const char * sync, int len) const
+VcdEntries::SEEKRES VcdEntries::seek_sync(FILE *fpi, const std::array<char, 12> & sync) const
 {
     char ch;
 
@@ -331,21 +322,21 @@ VcdEntries::SEEKRES VcdEntries::seek_sync(FILE *fpi, const char * sync, int len)
         return SEEKRES_NOTFOUND;
     }
 
-    for (int n = 0; n < len; n++)
+    for (size_t n = 1; n <= sync.size(); n++)
     {
-        if (ch != *(sync + n))
+        if (ch != sync[n - 1])
         {
-            if (n > 0)
+            if (n > 1)
             {
                 // Restart check
-                n = -1;
+                n = 0;
                 continue;
             }
 
-            n = -1;
+            n = 0;
         }
 
-        if (n == len - 1)
+        if (n == sync.size())
         {
             // Found!
             break;
