@@ -21,8 +21,8 @@
  * @ingroup ffmpegfs
  *
  * @author Norbert Schlia (nschlia@oblivion-software.de)
- * @copyright Copyright (C) 2013-2022 Norbert Schlia (nschlia@oblivion-software.de) @n
- * From BullysPLayer Copyright (C) 1984-2022 by Oblivion Software/Norbert Schlia
+ * @copyright Copyright (C) 2013-2023 Norbert Schlia (nschlia@oblivion-software.de) @n
+ * From BullysPLayer Copyright (C) 1984-2023 by Oblivion Software/Norbert Schlia
  */
 
 #ifndef VCDENTRIES_H
@@ -33,6 +33,7 @@
 #include "vcdchapter.h"
 
 #include <vector>
+#include <array>
 
 /** @brief Video CD entries
  */
@@ -58,7 +59,7 @@ public:
     /**
      * @brief Destroy VcdEntries object
      */
-    virtual ~VcdEntries();
+    virtual ~VcdEntries() = default;
 
     /**
      * @brief Reset this object
@@ -138,10 +139,9 @@ protected:
      * @brief Seek for sync bytes.
      * @param[in] fpi - file pointer of open file
      * @param[in] sync - sync bytes
-     * @param[in] len - length of sync bytes
      * @return Returns SEEKRES result code.
      */
-    SEEKRES                     seek_sync(FILE *fpi, const char * sync, int len) const;
+    SEEKRES                     seek_sync(FILE *fpi, const std::array<char, 12> & sync) const;
 
 protected:
     // Common data
