@@ -21,15 +21,15 @@
  * @ingroup ffmpegfs
  *
  * @author Norbert Schlia (nschlia@oblivion-software.de)
- * @copyright Copyright (C) 2013-2022 Norbert Schlia (nschlia@oblivion-software.de) @n
- * From BullysPLayer Copyright (C) 1984-2022 by Oblivion Software/Norbert Schlia
+ * @copyright Copyright (C) 2013-2023 Norbert Schlia (nschlia@oblivion-software.de) @n
+ * From BullysPLayer Copyright (C) 1984-2023 by Oblivion Software/Norbert Schlia
  */
 
-#pragma once
-
 #ifndef VCDINFO_H
 #define VCDINFO_H
 
+#pragma once
+
 #include "vcdchapter.h"
 
 /**
@@ -45,7 +45,7 @@ public:
     /**
      * @brief Destruct VcdInfo object
      */
-    virtual ~VcdInfo();
+    virtual ~VcdInfo() = default;
 
     /**
      * @brief Reset this object
