@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,14 +23,15 @@
  * @ingroup ffmpegfs
  *
  * @author Norbert Schlia (nschlia@oblivion-software.de)
- * @copyright Copyright (C) 2013-2022 Norbert Schlia (nschlia@oblivion-software.de) @n
- * From BullysPLayer Copyright (C) 1984-2022 by Oblivion Software/Norbert Schlia
+ * @copyright Copyright (C) 2013-2023 Norbert Schlia (nschlia@oblivion-software.de) @n
+ * From BullysPLayer Copyright (C) 1984-2023 by Oblivion Software/Norbert Schlia
  */
 
+#include "ffmpegfs.h"
 #include "vcdutils.h"
 #include "ffmpeg_utils.h"
 
-#include <string.h>
+#include <cstring>
 #include <unistd.h>
 #include <sys/stat.h>
 
@@ -87,10 +88,10 @@ bool locate_file(const std::string & path, const std::string & filename, std::st
 
 int locate_video(const std::string & path, int track_no, std::string & fullname)
 {
-    char buffer[PATH_MAX + 1];
+    std::string buffer;
 
     // Try VCD
-    snprintf(buffer, sizeof(buffer) - 1, "MPEGAV/AVSEQ%02i.DAT", track_no - 1);
+    strsprintf(&buffer, "MPEGAV/AVSEQ%02i.DAT", track_no - 1);
     fullname = path + buffer;
     if (!access(fullname.c_str(), F_OK))
     {
@@ -98,7 +99,7 @@ int locate_video(const std::string & path, int track_no, std::string & fullname)
     }
 
     // Try SVCD
-    snprintf(buffer, sizeof(buffer) - 1, "MPEG2/AVSEQ%02i.MPG", track_no - 1);
+    strsprintf(&buffer, "MPEG2/AVSEQ%02i.MPG", track_no - 1);
     fullname = path + buffer;
     if (!access(fullname.c_str(), F_OK))
     {
