@@ -21,8 +21,8 @@
  * @ingroup ffmpegfs
  *
  * @author Norbert Schlia (nschlia@oblivion-software.de)
- * @copyright Copyright (C) 2013-2022 Norbert Schlia (nschlia@oblivion-software.de) @n
- * From BullysPLayer Copyright (C) 1984-2022 by Oblivion Software/Norbert Schlia
+ * @copyright Copyright (C) 2013-2023 Norbert Schlia (nschlia@oblivion-software.de) @n
+ * From BullysPLayer Copyright (C) 1984-2023 by Oblivion Software/Norbert Schlia
  */
 
 #ifndef VCDUTILS_H
@@ -31,6 +31,7 @@
 #pragma once
 
 #include <string>
+#include <array>
 
 /** Convert BCD value to hex
  */
@@ -107,7 +108,7 @@ typedef struct VCDENTRIES
 typedef const VCDENTRY * LPCVCDENTRIES;     /**< @brief Pointer to const version of VCDENTRY */
 #pragma pack(pop)
 
-extern const char SYNC[12];                 /**< @brief Chapter synchronisation in S/VCD mpeg/dat files (12 byte: 0x00FFFFFFFFFFFFFFFFFFFF00) */
+extern const std::array<char, 12> SYNC;     /**< @brief Chapter synchronisation in S/VCD mpeg/dat files (12 byte: 0x00FFFFFFFFFFFFFFFFFFFF00) */
 
 /** @namespace VCDUTILS
  *  @brief Video CD utility functions
