@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@
  * @ingroup ffmpegfs
  *
  * @author Norbert Schlia (nschlia@oblivion-software.de)
- * @copyright Copyright (C) 2017-2022 Norbert Schlia (nschlia@oblivion-software.de)
+ * @copyright Copyright (C) 2017-2023 Norbert Schlia (nschlia@oblivion-software.de)
  */
 
 #include "vcdio.h"
@@ -52,7 +52,7 @@ VcdIO::VcdIO()
 
 VcdIO::~VcdIO()
 {
-    _close();
+    pvt_close();
 }
 
 VIRTUALTYPE VcdIO::type() const
@@ -65,7 +65,7 @@ size_t VcdIO::bufsize() const
     return (32 * 1024);
 }
 
-int VcdIO::open(LPVIRTUALFILE virtualfile)
+int VcdIO::openio(LPVIRTUALFILE virtualfile)
 {
     std::string src_filename;
 
@@ -102,7 +102,7 @@ int VcdIO::open(LPVIRTUALFILE virtualfile)
     return seek(0, SEEK_SET);
 }
 
-size_t VcdIO::read(void * data, size_t size)
+size_t VcdIO::readio(void * data, size_t size)
 {
     if (static_cast<size_t>(ftell(m_fpi)) + size > m_end_pos)
     {
@@ -196,12 +196,12 @@ bool VcdIO::eof() const
     return ((feof(m_fpi) || (static_cast<uint64_t>(ftell(m_fpi)) >= m_end_pos)) ? true : false);
 }
 
-void VcdIO::close()
+void VcdIO::closeio()
 {
-    _close();
+    pvt_close();
 }
 
-void VcdIO::_close()
+void VcdIO::pvt_close()
 {
     FILE *fpi = m_fpi;
     if (fpi != nullptr)
